@@ -1,28 +1,24 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Platforms\Keywords;
 
 use function array_merge;
 
 /**
  * MySQL 8.0 reserved keywords list.
+ *
+ * @deprecated
  */
-class MySQL80Keywords extends MySQL57Keywords
+class MySQL80Keywords extends MySQLKeywords
 {
     /**
-     * {@inheritdoc}
-     */
-    public function getName()
-    {
-        return 'MySQL80';
-    }
-
-    /**
-     * {@inheritdoc}
+     * {@inheritDoc}
      *
      * @link https://dev.mysql.com/doc/refman/8.0/en/keywords.html
      */
-    protected function getKeywords()
+    protected function getKeywords(): array
     {
         $keywords = parent::getKeywords();
 
