@@ -10,36 +10,56 @@ use Doctrine\DBAL\Schema\Exception\ForeignKeyDoesNotExist;
 use Doctrine\DBAL\Schema\Exception\IndexAlreadyExists;
 use Doctrine\DBAL\Schema\Exception\IndexDoesNotExist;
 use Doctrine\DBAL\Schema\Exception\IndexNameInvalid;
+use Doctrine\DBAL\Schema\Exception\InvalidState;
 use Doctrine\DBAL\Schema\Exception\InvalidTableName;
+use Doctrine\DBAL\Schema\Exception\PrimaryKeyAlreadyExists;
 use Doctrine\DBAL\Schema\Exception\UniqueConstraintDoesNotExist;
+use Doctrine\DBAL\Schema\Name\OptionallyQualifiedName;
+use Doctrine\DBAL\Schema\Name\Parser\OptionallyQualifiedNameParser;
+use Doctrine\DBAL\Schema\Name\Parsers;
+use Doctrine\DBAL\Schema\Name\UnqualifiedName;
+use Doctrine\DBAL\Types\Exception\TypesException;
 use Doctrine\DBAL\Types\Type;
+use Doctrine\Deprecations\Deprecation;
 use LogicException;
 
+use function array_diff_key;
+use function array_map;
 use function array_merge;
 use function array_values;
+use function assert;
+use function count;
+use function implode;
 use function in_array;
-use function is_string;
 use function preg_match;
 use function sprintf;
 use function strtolower;
 
 /**
  * Object Representation of a table.
+ *
+ * @extends AbstractNamedObject<OptionallyQualifiedName>
  */
-class Table extends AbstractAsset
+class Table extends AbstractNamedObject
 {
     /** @var Column[] */
     protected array $_columns = [];
 
-    /** @var Index[] */
-    private array $implicitIndexes = [];
-
     /** @var array<string, string> keys are new names, values are old names */
     protected array $renamedColumns = [];
 
     /** @var Index[] */
     protected array $_indexes = [];
 
+    /**
+     * The keys of this array are the names of the indexes that were implicitly created as backing for foreign key
+     * constraints. The values are not used but must be non-null for {@link isset()} to work correctly.
+     *
+     * @var array<string,true>
+     */
+    private array $implicitIndexNames = [];
+
+    /** @deprecated Use {@see $primaryKeyConstraint} instead. */
     protected ?string $_primaryKeyName = null;
 
     /** @var UniqueConstraint[] */
@@ -53,8 +73,16 @@ class Table extends AbstractAsset
         'create_options' => [],
     ];
 
+    /** @deprecated Pass a {@link TableConfiguration} instance to the constructor instead. */
     protected ?SchemaConfig $_schemaConfig = null;
 
+    /** @var positive-int */
+    private int $maxIdentifierLength;
+
+    private ?PrimaryKeyConstraint $primaryKeyConstraint = null;
+
+    private bool $failedToParsePrimaryKeyConstraint = false;
+
     /**
      * @param array<Column>               $columns
      * @param array<Index>                $indexes
@@ -69,12 +97,18 @@ class Table extends AbstractAsset
         array $uniqueConstraints = [],
         array $fkConstraints = [],
         array $options = [],
+        ?TableConfiguration $configuration = null,
+        ?PrimaryKeyConstraint $primaryKeyConstraint = null,
     ) {
         if ($name === '') {
             throw InvalidTableName::new($name);
         }
 
-        $this->_setName($name);
+        parent::__construct($name);
+
+        $configuration ??= (new SchemaConfig())->toTableConfiguration();
+
+        $this->maxIdentifierLength = $configuration->getMaxIdentifierLength();
 
         foreach ($columns as $column) {
             $this->_addColumn($column);
@@ -84,6 +118,10 @@ class Table extends AbstractAsset
             $this->_addIndex($idx);
         }
 
+        if ($primaryKeyConstraint !== null) {
+            $this->addPrimaryKeyConstraint($primaryKeyConstraint);
+        }
+
         foreach ($uniqueConstraints as $uniqueConstraint) {
             $this->_addUniqueConstraint($uniqueConstraint);
         }
@@ -95,18 +133,42 @@ class Table extends AbstractAsset
         $this->_options = array_merge($this->_options, $options);
     }
 
+    protected function getNameParser(): OptionallyQualifiedNameParser
+    {
+        return Parsers::getOptionallyQualifiedNameParser();
+    }
+
+    /** @deprecated Pass a {@link TableConfiguration} instance to the constructor instead. */
     public function setSchemaConfig(SchemaConfig $schemaConfig): void
     {
+        Deprecation::triggerIfCalledFromOutside(
+            'doctrine/dbal',
+            'https://github.com/doctrine/dbal/pull/6635',
+            '%s is deprecated. Pass TableConfiguration to the constructor instead.',
+            __METHOD__,
+        );
+
         $this->_schemaConfig = $schemaConfig;
+
+        $this->maxIdentifierLength = $schemaConfig->getMaxIdentifierLength();
     }
 
     /**
      * Sets the Primary Key.
      *
-     * @param array<int, string> $columnNames
+     * @deprecated Use {@see addPrimaryKeyConstraint()} instead.
+     *
+     * @param non-empty-list<string> $columnNames
      */
     public function setPrimaryKey(array $columnNames, ?string $indexName = null): self
     {
+        Deprecation::triggerIfCalledFromOutside(
+            'doctrine/dbal',
+            'https://github.com/doctrine/dbal/pull/6867',
+            '%s() is deprecated. Use Table::addPrimaryKeyConstraint() instead.',
+            __METHOD__,
+        );
+
         if ($indexName === null) {
             $indexName = 'primary';
         }
@@ -115,16 +177,49 @@ class Table extends AbstractAsset
 
         foreach ($columnNames as $columnName) {
             $column = $this->getColumn($columnName);
+
+            if (! $column->getNotnull()) {
+                Deprecation::trigger(
+                    'doctrine/dbal',
+                    'https://github.com/doctrine/dbal/pull/6787',
+                    'Using nullable columns (%s.%s) in a primary key index is deprecated.',
+                    $this->getName(),
+                    $columnName,
+                );
+            }
+
             $column->setNotnull(true);
         }
 
         return $this;
     }
 
+    public function addPrimaryKeyConstraint(PrimaryKeyConstraint $primaryKeyConstraint): self
+    {
+        $this->setPrimaryKey(
+            array_map(
+                static fn (UnqualifiedName $columnName): string => $columnName->toString(),
+                $primaryKeyConstraint->getColumnNames(),
+            ),
+            $primaryKeyConstraint->getObjectName()?->toString(),
+        );
+
+        // there is no way to set a primary index with flags. we have to set it and then add the flag
+        if (! $primaryKeyConstraint->isClustered()) {
+            $index = $this->getPrimaryKey();
+            assert($index !== null);
+            $index->addFlag('nonclustered');
+        }
+
+        $this->primaryKeyConstraint = $primaryKeyConstraint;
+
+        return $this;
+    }
+
     /**
-     * @param array<int, string>   $columnNames
-     * @param array<int, string>   $flags
-     * @param array<string, mixed> $options
+     * @param non-empty-list<string> $columnNames
+     * @param array<int, string>     $flags
+     * @param array<string, mixed>   $options
      */
     public function addUniqueConstraint(
         array $columnNames,
@@ -142,9 +237,9 @@ class Table extends AbstractAsset
     }
 
     /**
-     * @param array<int, string>   $columnNames
-     * @param array<int, string>   $flags
-     * @param array<string, mixed> $options
+     * @param non-empty-list<string> $columnNames
+     * @param array<int, string>     $flags
+     * @param array<string, mixed>   $options
      */
     public function addIndex(
         array $columnNames,
@@ -166,6 +261,9 @@ class Table extends AbstractAsset
      */
     public function dropPrimaryKey(): void
     {
+        $this->primaryKeyConstraint              = null;
+        $this->failedToParsePrimaryKeyConstraint = false;
+
         if ($this->_primaryKeyName === null) {
             return;
         }
@@ -189,8 +287,8 @@ class Table extends AbstractAsset
     }
 
     /**
-     * @param array<int, string>   $columnNames
-     * @param array<string, mixed> $options
+     * @param non-empty-list<string> $columnNames
+     * @param array<string, mixed>   $options
      */
     public function addUniqueIndex(array $columnNames, ?string $indexName = null, array $options = []): self
     {
@@ -212,30 +310,41 @@ class Table extends AbstractAsset
      */
     public function renameIndex(string $oldName, ?string $newName = null): self
     {
-        $oldName           = $this->normalizeIdentifier($oldName);
-        $normalizedNewName = $this->normalizeIdentifier($newName);
-
-        if ($oldName === $normalizedNewName) {
-            return $this;
-        }
-
         if (! $this->hasIndex($oldName)) {
             throw IndexDoesNotExist::new($oldName, $this->_name);
         }
 
-        if ($this->hasIndex($normalizedNewName)) {
-            throw IndexAlreadyExists::new($normalizedNewName, $this->_name);
+        $normalizedOldName = $this->normalizeIdentifier($oldName);
+
+        if ($newName !== null) {
+            $normalizedNewName = $this->normalizeIdentifier($newName);
+
+            if ($normalizedOldName === $normalizedNewName) {
+                return $this;
+            }
+
+            if ($this->hasIndex($newName)) {
+                throw IndexAlreadyExists::new($newName, $this->_name);
+            }
         }
 
-        $oldIndex = $this->_indexes[$oldName];
+        $oldIndex = $this->_indexes[$normalizedOldName];
 
         if ($oldIndex->isPrimary()) {
+            Deprecation::triggerIfCalledFromOutside(
+                'doctrine/dbal',
+                'https://github.com/doctrine/dbal/pull/6867',
+                'Renaming primary key constraint via %s() is deprecated. Use Table::dropPrimaryKey() and '
+                    . ' Table::addPrimaryKeyConstraint() instead.',
+                __METHOD__,
+            );
+
             $this->dropPrimaryKey();
 
             return $this->setPrimaryKey($oldIndex->getColumns(), $newName ?? null);
         }
 
-        unset($this->_indexes[$oldName]);
+        unset($this->_indexes[$normalizedOldName]);
 
         if ($oldIndex->isUnique()) {
             return $this->addUniqueIndex($oldIndex->getColumns(), $newName, $oldIndex->getOptions());
@@ -247,10 +356,19 @@ class Table extends AbstractAsset
     /**
      * Checks if an index begins in the order of the given columns.
      *
+     * @deprecated
+     *
      * @param array<int, string> $columnNames
      */
     public function columnsAreIndexed(array $columnNames): bool
     {
+        Deprecation::trigger(
+            'doctrine/dbal',
+            'https://github.com/doctrine/dbal/pull/6710',
+            '%s is deprecated.',
+            __METHOD__,
+        );
+
         foreach ($this->getIndexes() as $index) {
             if ($index->spansColumns($columnNames)) {
                 return true;
@@ -260,7 +378,11 @@ class Table extends AbstractAsset
         return false;
     }
 
-    /** @param array<string, mixed> $options */
+    /**
+     * @param array<string, mixed> $options
+     *
+     * @throws TypesException
+     */
     public function addColumn(string $name, string $typeName, array $options = []): Column
     {
         $column = new Column($name, Type::getType($typeName), $options);
@@ -276,7 +398,12 @@ class Table extends AbstractAsset
         return $this->renamedColumns;
     }
 
-    /** @throws LogicException */
+    /**
+     * @param non-empty-string $oldName
+     * @param non-empty-string $newName
+     *
+     * @throws LogicException
+     */
     final public function renameColumn(string $oldName, string $newName): Column
     {
         $oldName = $this->normalizeIdentifier($oldName);
@@ -291,10 +418,15 @@ class Table extends AbstractAsset
         }
 
         $column = $this->getColumn($oldName);
-        $column->_setName($newName);
+
+        $column->_name = $newName;
         unset($this->_columns[$oldName]);
         $this->_addColumn($column);
 
+        $this->renameColumnInIndexes($oldName, $newName);
+        $this->renameColumnInForeignKeyConstraints($oldName, $newName);
+        $this->renameColumnInUniqueConstraints($oldName, $newName);
+
         // If a column is renamed multiple times, we only want to know the original and last new name
         if (isset($this->renamedColumns[$oldName])) {
             $toRemove = $oldName;
@@ -325,6 +457,30 @@ class Table extends AbstractAsset
     {
         $name = $this->normalizeIdentifier($name);
 
+        $foreignKeyConstraintNames = $this->getForeignKeyConstraintNamesByLocalColumnName($name);
+        $uniqueConstraintNames     = $this->getUniqueConstraintNamesByColumnName($name);
+
+        if (count($foreignKeyConstraintNames) > 0 || count($uniqueConstraintNames) > 0) {
+            $constraints = [];
+
+            if (count($foreignKeyConstraintNames) > 0) {
+                $constraints[] = 'foreign key constraints: ' . implode(', ', $foreignKeyConstraintNames);
+            }
+
+            if (count($uniqueConstraintNames) > 0) {
+                $constraints[] = 'unique constraints: ' . implode(', ', $uniqueConstraintNames);
+            }
+
+            Deprecation::trigger(
+                'doctrine/dbal',
+                'https://github.com/doctrine/dbal/pull/6559',
+                'Dropping columns referenced by constraints is deprecated.'
+                    . ' Column %s is used by the following constraints: %s ',
+                $name,
+                implode('; ', $constraints),
+            );
+        }
+
         unset($this->_columns[$name]);
 
         return $this;
@@ -335,9 +491,9 @@ class Table extends AbstractAsset
      *
      * Name is inferred from the local columns.
      *
-     * @param array<int, string>   $localColumnNames
-     * @param array<int, string>   $foreignColumnNames
-     * @param array<string, mixed> $options
+     * @param non-empty-list<string> $localColumnNames
+     * @param non-empty-list<string> $foreignColumnNames
+     * @param array<string, mixed>   $options
      */
     public function addForeignKeyConstraint(
         string $foreignTableName,
@@ -402,8 +558,24 @@ class Table extends AbstractAsset
 
     /**
      * Removes the foreign key constraint with the given name.
+     *
+     * @deprecated Use {@link dropForeignKey()} instead.
      */
     public function removeForeignKey(string $name): void
+    {
+        Deprecation::trigger(
+            'doctrine/dbal',
+            'https://github.com/doctrine/dbal/pull/6560',
+            'Table::removeForeignKey() is deprecated. Use Table::dropForeignKey() instead.',
+        );
+
+        $this->dropForeignKey($name);
+    }
+
+    /**
+     * Drops the foreign key constraint with the given name.
+     */
+    public function dropForeignKey(string $name): void
     {
         $name = $this->normalizeIdentifier($name);
 
@@ -440,8 +612,24 @@ class Table extends AbstractAsset
 
     /**
      * Removes the unique constraint with the given name.
+     *
+     * @deprecated Use {@link dropUniqueConstraint()} instead.
      */
     public function removeUniqueConstraint(string $name): void
+    {
+        Deprecation::trigger(
+            'doctrine/dbal',
+            'https://github.com/doctrine/dbal/pull/6560',
+            'Table::removeUniqueConstraint() is deprecated. Use Table::dropUniqueConstraint() instead.',
+        );
+
+        $this->dropUniqueConstraint($name);
+    }
+
+    /**
+     * Drops the unique constraint with the given name.
+     */
+    public function dropUniqueConstraint(string $name): void
     {
         $name = $this->normalizeIdentifier($name);
 
@@ -488,9 +676,18 @@ class Table extends AbstractAsset
 
     /**
      * Returns the primary key.
+     *
+     * @deprecated Use {@see getPrimaryKeyConstraint()} instead.
      */
     public function getPrimaryKey(): ?Index
     {
+        Deprecation::triggerIfCalledFromOutside(
+            'doctrine/dbal',
+            'https://github.com/doctrine/dbal/pull/6867',
+            '%s() is deprecated. Use Table::getPrimaryKeyConstraint() instead.',
+            __METHOD__,
+        );
+
         if ($this->_primaryKeyName !== null) {
             return $this->getIndex($this->_primaryKeyName);
         }
@@ -498,6 +695,15 @@ class Table extends AbstractAsset
         return null;
     }
 
+    public function getPrimaryKeyConstraint(): ?PrimaryKeyConstraint
+    {
+        if ($this->failedToParsePrimaryKeyConstraint) {
+            throw InvalidState::tableHasInvalidPrimaryKeyConstraint($this->getName());
+        }
+
+        return $this->primaryKeyConstraint;
+    }
+
     /**
      * Returns whether this table has an Index with the given name.
      */
@@ -582,11 +788,21 @@ class Table extends AbstractAsset
         }
     }
 
+    /**
+     * @deprecated
+     *
+     * @return positive-int
+     */
     protected function _getMaxIdentifierLength(): int
     {
-        return $this->_schemaConfig instanceof SchemaConfig
-            ? $this->_schemaConfig->getMaxIdentifierLength()
-            : 63;
+        Deprecation::triggerIfCalledFromOutside(
+            'doctrine/dbal',
+            'https://github.com/doctrine/dbal/pull/6635',
+            '%s is deprecated.',
+            __METHOD__,
+        );
+
+        return $this->maxIdentifierLength;
     }
 
     protected function _addColumn(Column $column): void
@@ -604,40 +820,75 @@ class Table extends AbstractAsset
     /**
      * Adds an index to the table.
      */
-    protected function _addIndex(Index $indexCandidate): self
+    protected function _addIndex(Index $index): self
     {
-        $indexName               = $indexCandidate->getName();
-        $indexName               = $this->normalizeIdentifier($indexName);
-        $replacedImplicitIndexes = [];
+        $indexName = $this->normalizeIdentifier($index->getName());
 
-        foreach ($this->implicitIndexes as $name => $implicitIndex) {
-            if (! $implicitIndex->isFulfilledBy($indexCandidate) || ! isset($this->_indexes[$name])) {
+        $replacedImplicitIndexNames = [];
+
+        foreach ($this->implicitIndexNames as $implicitIndexName => $_) {
+            if (! isset($this->_indexes[$implicitIndexName])) {
                 continue;
             }
 
-            $replacedImplicitIndexes[] = $name;
+            if (! $this->_indexes[$implicitIndexName]->isFulfilledBy($index)) {
+                continue;
+            }
+
+            $replacedImplicitIndexNames[$implicitIndexName] = true;
         }
 
-        if (
-            (isset($this->_indexes[$indexName]) && ! in_array($indexName, $replacedImplicitIndexes, true)) ||
-            ($this->_primaryKeyName !== null && $indexCandidate->isPrimary())
-        ) {
+        if ($this->_primaryKeyName !== null && $index->isPrimary()) {
+            throw PrimaryKeyAlreadyExists::new($this->_name);
+        }
+
+        if (isset($this->_indexes[$indexName]) && ! isset($replacedImplicitIndexNames[$indexName])) {
             throw IndexAlreadyExists::new($indexName, $this->_name);
         }
 
-        foreach ($replacedImplicitIndexes as $name) {
-            unset($this->_indexes[$name], $this->implicitIndexes[$name]);
+        foreach ($replacedImplicitIndexNames as $name => $_) {
+            unset($this->_indexes[$name], $this->implicitIndexNames[$name]);
         }
 
-        if ($indexCandidate->isPrimary()) {
+        if ($index->isPrimary()) {
             $this->_primaryKeyName = $indexName;
+
+            try {
+                $this->primaryKeyConstraint              = $this->parsePrimaryKeyConstraint($index);
+                $this->failedToParsePrimaryKeyConstraint = false;
+            } catch (InvalidState) {
+                $this->primaryKeyConstraint              = null;
+                $this->failedToParsePrimaryKeyConstraint = true;
+            }
         }
 
-        $this->_indexes[$indexName] = $indexCandidate;
+        $this->_indexes[$indexName] = $index;
 
         return $this;
     }
 
+    private function parsePrimaryKeyConstraint(Index $index): ?PrimaryKeyConstraint
+    {
+        $indexedColumns = $index->getIndexedColumns();
+
+        $columnNames = [];
+        foreach ($indexedColumns as $indexedColumn) {
+            if ($indexedColumn->getLength() !== null) {
+                return null;
+            }
+
+            $columnNames[] = $indexedColumn->getColumnName();
+        }
+
+        // Do not derive the constraint name from the index name in the upgrade path. The primary index name defaults to
+        // "PRIMARY", while the default constraint name is null (unspecified, to be generated by the database platform).
+        return new PrimaryKeyConstraint(
+            null,
+            $columnNames,
+            ! $index->hasFlag('nonclustered'),
+        );
+    }
+
     protected function _addUniqueConstraint(UniqueConstraint $constraint): self
     {
         $name = $constraint->getName() !== ''
@@ -669,7 +920,7 @@ class Table extends AbstractAsset
             }
         }
 
-        $this->implicitIndexes[$this->normalizeIdentifier($indexName)] = $indexCandidate;
+        $this->implicitIndexNames[$this->normalizeIdentifier($indexName)] = true;
 
         return $this;
     }
@@ -707,7 +958,7 @@ class Table extends AbstractAsset
         }
 
         $this->_addIndex($indexCandidate);
-        $this->implicitIndexes[$this->normalizeIdentifier($indexName)] = $indexCandidate;
+        $this->implicitIndexNames[$this->normalizeIdentifier($indexName)] = true;
 
         return $this;
     }
@@ -716,13 +967,12 @@ class Table extends AbstractAsset
      * Normalizes a given identifier.
      *
      * Trims quotes and lowercases the given identifier.
+     *
+     * @return non-empty-string
      */
-    private function normalizeIdentifier(?string $identifier): string
+    private function normalizeIdentifier(string $identifier): string
     {
-        if ($identifier === null) {
-            return '';
-        }
-
+        /** @phpstan-ignore return.type */
         return $this->trimQuotes(strtolower($identifier));
     }
 
@@ -740,9 +990,44 @@ class Table extends AbstractAsset
     }
 
     /**
-     * @param array<string|int, string> $columns
-     * @param array<int, string>        $flags
-     * @param array<string, mixed>      $options
+     * Instantiates a new table editor.
+     */
+    public static function editor(): TableEditor
+    {
+        return new TableEditor();
+    }
+
+    /**
+     * Instantiates a new table editor and initializes it with the table's properties.
+     */
+    public function edit(): TableEditor
+    {
+        $editor = self::editor()
+            ->setName($this->getObjectName())
+            ->setColumns(...array_values($this->_columns))
+            ->setIndexes(...array_values(array_diff_key($this->_indexes, $this->implicitIndexNames)))
+            ->setPrimaryKeyConstraint($this->primaryKeyConstraint)
+            ->setUniqueConstraints(...array_values($this->uniqueConstraints))
+            ->setForeignKeyConstraints(...array_values($this->_fkConstraints));
+
+        $options = $this->_options;
+
+        if (isset($options['comment'])) {
+            $editor->setComment($options['comment']);
+            unset($options['comment']);
+        }
+
+        return $editor
+            ->setOptions($options)
+            ->setConfiguration(
+                new TableConfiguration($this->maxIdentifierLength),
+            );
+    }
+
+    /**
+     * @param non-empty-list<string> $columns
+     * @param array<int, string>     $flags
+     * @param array<string, mixed>   $options
      */
     private function _createUniqueConstraint(
         array $columns,
@@ -754,13 +1039,7 @@ class Table extends AbstractAsset
             throw IndexNameInvalid::new($indexName);
         }
 
-        foreach ($columns as $index => $value) {
-            if (is_string($index)) {
-                $columnName = $index;
-            } else {
-                $columnName = $value;
-            }
-
+        foreach ($columns as $columnName) {
             if (! $this->hasColumn($columnName)) {
                 throw ColumnDoesNotExist::new($columnName, $this->_name);
             }
@@ -770,9 +1049,9 @@ class Table extends AbstractAsset
     }
 
     /**
-     * @param array<int, string>   $columns
-     * @param array<int, string>   $flags
-     * @param array<string, mixed> $options
+     * @param non-empty-list<string> $columns
+     * @param array<int, string>     $flags
+     * @param array<string, mixed>   $options
      */
     private function _createIndex(
         array $columns,
@@ -794,4 +1073,129 @@ class Table extends AbstractAsset
 
         return new Index($indexName, $columns, $isUnique, $isPrimary, $flags, $options);
     }
+
+    /** @param non-empty-string $newName */
+    private function renameColumnInIndexes(string $oldName, string $newName): void
+    {
+        foreach ($this->_indexes as $key => $index) {
+            $modified = false;
+            $columns  = [];
+            foreach ($index->getColumns() as $columnName) {
+                if ($columnName === $oldName) {
+                    $columns[] = $newName;
+                    $modified  = true;
+                } else {
+                    $columns[] = $columnName;
+                }
+            }
+
+            if (! $modified) {
+                continue;
+            }
+
+            $this->_indexes[$key] = new Index(
+                $index->getName(),
+                $columns,
+                $index->isUnique(),
+                $index->isPrimary(),
+                $index->getFlags(),
+                $index->getOptions(),
+            );
+        }
+    }
+
+    /**
+     * @param non-empty-string $oldName
+     * @param non-empty-string $newName
+     */
+    private function renameColumnInForeignKeyConstraints(string $oldName, string $newName): void
+    {
+        foreach ($this->_fkConstraints as $key => $constraint) {
+            $modified     = false;
+            $localColumns = [];
+            foreach ($constraint->getLocalColumns() as $columnName) {
+                if ($columnName === $oldName) {
+                    $localColumns[] = $newName;
+                    $modified       = true;
+                } else {
+                    $localColumns[] = $columnName;
+                }
+            }
+
+            if (! $modified) {
+                continue;
+            }
+
+            $this->_fkConstraints[$key] = new ForeignKeyConstraint(
+                $localColumns, // @phpstan-ignore argument.type
+                $constraint->getForeignTableName(),
+                $constraint->getForeignColumns(), // @phpstan-ignore argument.type
+                $constraint->getName(),
+                $constraint->getOptions(),
+            );
+        }
+    }
+
+    /**
+     * @param non-empty-string $oldName
+     * @param non-empty-string $newName
+     */
+    private function renameColumnInUniqueConstraints(string $oldName, string $newName): void
+    {
+        foreach ($this->uniqueConstraints as $key => $constraint) {
+            $modified = false;
+            $columns  = [];
+            foreach ($constraint->getColumns() as $columnName) {
+                if ($columnName === $oldName) {
+                    $columns[] = $newName;
+                    $modified  = true;
+                } else {
+                    $columns[] = $columnName;
+                }
+            }
+
+            if (! $modified) {
+                continue;
+            }
+
+            $this->uniqueConstraints[$key] = new UniqueConstraint(
+                $constraint->getName(),
+                $columns, // @phpstan-ignore argument.type
+                $constraint->getFlags(),
+                $constraint->getOptions(),
+            );
+        }
+    }
+
+    /** @return list<string> */
+    private function getForeignKeyConstraintNamesByLocalColumnName(string $columnName): array
+    {
+        $names = [];
+
+        foreach ($this->_fkConstraints as $name => $constraint) {
+            if (! in_array($columnName, $constraint->getLocalColumns(), true)) {
+                continue;
+            }
+
+            $names[] = $name;
+        }
+
+        return $names;
+    }
+
+    /** @return list<string> */
+    private function getUniqueConstraintNamesByColumnName(string $columnName): array
+    {
+        $names = [];
+
+        foreach ($this->uniqueConstraints as $name => $constraint) {
+            if (! in_array($columnName, $constraint->getColumns(), true)) {
+                continue;
+            }
+
+            $names[] = $name;
+        }
+
+        return $names;
+    }
 }
