@@ -1,17 +1,17 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Driver\AbstractOracleDriver;
 
 use Doctrine\DBAL\Driver\AbstractOracleDriver\EasyConnectString;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
 class EasyConnectStringTest extends TestCase
 {
-    /**
-     * @param mixed[] $params
-     *
-     * @dataProvider connectionParametersProvider
-     */
+    /** @param mixed[] $params */
+    #[DataProvider('connectionParametersProvider')]
     public function testFromConnectionParameters(array $params, string $expected): void
     {
         $string = EasyConnectString::fromConnectionParameters($params);
@@ -19,7 +19,7 @@ class EasyConnectStringTest extends TestCase
         self::assertSame($expected, (string) $string);
     }
 
-    /** @return mixed[] */
+    /** @return iterable<string, array<int, mixed>> */
     public static function connectionParametersProvider(): iterable
     {
         return [
@@ -57,6 +57,18 @@ class EasyConnectStringTest extends TestCase
                 '(DESCRIPTION=(ADDRESS=(PROTOCOL=TCP)(HOST=localhost)(PORT=41521))'
                     . '(CONNECT_DATA=(SID=XE)(INSTANCE_NAME=SALES)(SERVER=POOLED)))',
             ],
+            'tcps-params' => [
+                [
+                    'host' => 'localhost',
+                    'port' => 41521,
+                    'dbname' => 'XE',
+                    'instancename' => 'SALES',
+                    'pooled' => true,
+                    'driverOptions' => ['protocol' => 'TCPS'],
+                ],
+                '(DESCRIPTION=(ADDRESS=(PROTOCOL=TCPS)(HOST=localhost)(PORT=41521))'
+                . '(CONNECT_DATA=(SID=XE)(INSTANCE_NAME=SALES)(SERVER=POOLED)))',
+            ],
         ];
     }
 }
