@@ -1,22 +1,22 @@
 <?php
 
-namespace Doctrine\Tests\DBAL\Driver\IBMDB2;
+declare(strict_types=1);
+
+namespace Doctrine\DBAL\Tests\Driver\IBMDB2;
 
 use Doctrine\DBAL\Driver\IBMDB2\DataSourceName;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
 class DataSourceNameTest extends TestCase
 {
-    /**
-     * @param mixed[] $params
-     *
-     * @dataProvider connectionParametersProvider
-     */
+    /** @param mixed[] $params */
+    #[DataProvider('connectionParametersProvider')]
     public function testFromConnectionParameters(array $params, string $expected): void
     {
         $dsn = DataSourceName::fromConnectionParameters($params);
 
-        $this->assertSame($expected, $dsn->toString());
+        self::assertSame($expected, $dsn->toString());
     }
 
     /** @return iterable<string,array<int,mixed>> */
