@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Driver\Middleware;
 
 use Doctrine\DBAL\Driver\Middleware\AbstractStatementMiddleware;
@@ -15,10 +17,9 @@ final class AbstractStatementMiddlewareTest extends TestCase
         $statement = $this->createMock(Statement::class);
         $statement->expects(self::once())
             ->method('execute')
-            ->with(['foo' => 'bar'])
             ->willReturn($result);
 
-        self::assertSame($result, $this->createMiddleware($statement)->execute(['foo' => 'bar']));
+        self::assertSame($result, $this->createMiddleware($statement)->execute());
     }
 
     private function createMiddleware(Statement $statement): AbstractStatementMiddleware
