@@ -1,17 +1,20 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Driver\Mysqli;
 
 use Doctrine\DBAL\Driver\Mysqli\Driver;
 use Doctrine\DBAL\Driver\Mysqli\Exception\HostRequired;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
+use PHPUnit\Framework\Attributes\RequiresPhpExtension;
 
-/** @requires extension mysqli */
+#[RequiresPhpExtension('mysqli')]
 class ConnectionTest extends FunctionalTestCase
 {
     public function testHostnameIsRequiredForPersistentConnection(): void
     {
         $this->expectException(HostRequired::class);
-        (new Driver())->connect(['persistent' => 'true']);
+        (new Driver())->connect(['persistent' => true]);
     }
 }
