@@ -1,11 +1,15 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Driver\OCI8;
 
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\RequiresPhpExtension;
 
-/** @requires extension oci8 */
+#[RequiresPhpExtension('oci8')]
 class StatementTest extends FunctionalTestCase
 {
     protected function setUp(): void
@@ -20,9 +24,8 @@ class StatementTest extends FunctionalTestCase
     /**
      * @param mixed[] $params
      * @param mixed[] $expected
-     *
-     * @dataProvider queryConversionProvider
      */
+    #[DataProvider('queryConversionProvider')]
     public function testQueryConversion(string $query, array $params, array $expected): void
     {
         self::assertEquals(
@@ -31,24 +34,6 @@ class StatementTest extends FunctionalTestCase
         );
     }
 
-    /**
-     * Low-level approach to working with parameter binding
-     *
-     * @param mixed[] $params
-     * @param mixed[] $expected
-     *
-     * @dataProvider queryConversionProvider
-     */
-    public function testStatementBindParameters(string $query, array $params, array $expected): void
-    {
-        self::assertEquals(
-            $expected,
-            $this->connection->prepare($query)
-                ->execute($params)
-                ->fetchAssociative(),
-        );
-    }
-
     /** @return array<string, array<int, mixed>> */
     public static function queryConversionProvider(): iterable
     {
@@ -100,4 +85,16 @@ World?!',
             ],
         ];
     }
+
+    public function testBindPositionalParameter(): void
+    {
+        $statement = $this->connection->prepare('SELECT ? COL1 FROM DUAL');
+        $statement->bindValue(1, 1);
+
+        self::assertEquals(
+            ['COL1' => 1],
+            $statement->executeQuery()
+                ->fetchAssociative(),
+        );
+    }
 }
