@@ -6,17 +6,23 @@ namespace Doctrine\DBAL\Tests\Functional;
 
 use Doctrine\DBAL\Platforms\PostgreSQLPlatform;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
+use Doctrine\DBAL\Tests\TestUtil;
 use PHPUnit\Framework\Attributes\DataProvider;
 
 class FetchBooleanTest extends FunctionalTestCase
 {
     protected function setUp(): void
     {
-        if ($this->connection->getDatabasePlatform() instanceof PostgreSQLPlatform) {
+        if (
+            $this->connection->getDatabasePlatform() instanceof PostgreSQLPlatform
+            && ! TestUtil::isPdoStringifyFetchesEnabled()
+        ) {
             return;
         }
 
-        self::markTestSkipped('Only PostgreSQL supports boolean values natively');
+        self::markTestSkipped(
+            'Only PostgreSQL supports boolean values natively, as long as PDO does not stringify them.',
+        );
     }
 
     #[DataProvider('booleanLiteralProvider')]
