@@ -7,6 +7,8 @@ namespace Doctrine\DBAL\Tests\Functional;
 use Doctrine\DBAL\ArrayParameterType;
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\ParameterType;
+use Doctrine\DBAL\Schema\Column;
+use Doctrine\DBAL\Schema\PrimaryKeyConstraint;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Types\Types;
@@ -166,11 +168,30 @@ class NamedParametersTest extends FunctionalTestCase
         }
 
         try {
-            $table = new Table('ddc1372_foobar');
-            $table->addColumn('id', Types::INTEGER);
-            $table->addColumn('foo', Types::STRING, ['length' => 1]);
-            $table->addColumn('bar', Types::STRING, ['length' => 1]);
-            $table->setPrimaryKey(['id']);
+            $table = Table::editor()
+                ->setUnquotedName('ddc1372_foobar')
+                ->setColumns(
+                    Column::editor()
+                        ->setUnquotedName('id')
+                        ->setTypeName(Types::INTEGER)
+                        ->create(),
+                    Column::editor()
+                        ->setUnquotedName('foo')
+                        ->setTypeName(Types::STRING)
+                        ->setLength(1)
+                        ->create(),
+                    Column::editor()
+                        ->setUnquotedName('bar')
+                        ->setTypeName(Types::STRING)
+                        ->setLength(1)
+                        ->create(),
+                )
+                ->setPrimaryKeyConstraint(
+                    PrimaryKeyConstraint::editor()
+                        ->setUnquotedColumnNames('id')
+                        ->create(),
+                )
+                ->create();
 
             $sm = $this->connection->createSchemaManager();
             $sm->createTable($table);
