@@ -6,14 +6,12 @@ namespace Doctrine\DBAL\Tests\Functional\Platform;
 
 use Doctrine\DBAL\Platforms\SQLServerPlatform;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
+use PHPUnit\Framework\Attributes\DataProvider;
 
 final class LengthExpressionTest extends FunctionalTestCase
 {
-    /**
-     * @link https://docs.microsoft.com/en-us/sql/relational-databases/collations/collation-and-unicode-support
-     *
-     * @dataProvider expressionProvider
-     */
+    /** @link https://docs.microsoft.com/en-us/sql/relational-databases/collations/collation-and-unicode-support */
+    #[DataProvider('expressionProvider')]
     public function testLengthExpression(string $value, int $expected, bool $isMultibyte): void
     {
         $platform = $this->connection->getDatabasePlatform();
@@ -32,7 +30,7 @@ final class LengthExpressionTest extends FunctionalTestCase
         self::assertEquals($expected, $this->connection->fetchOne($query, [$value]));
     }
 
-    /** @return iterable<string,array{string,int}> */
+    /** @return iterable<string,array{string,int,bool}> */
     public static function expressionProvider(): iterable
     {
         yield '1-byte' => ['Hello, world!', 13, false];
