@@ -15,17 +15,40 @@ use PHPUnit\Framework\Attributes\DataProvider;
 
 class RenameColumnTest extends FunctionalTestCase
 {
-    /** @dataProvider columnNameProvider */
-    public function testColumnPositionRetainedAfterImplicitRenaming(string $columnName, string $newColumnName): void
+    /**
+     * @param non-empty-string $oldColumnName
+     * @param non-empty-string $newColumnName
+     */
+    #[DataProvider('columnNameProvider')]
+    public function testColumnPositionRetainedAfterImplicitRenaming(string $oldColumnName, string $newColumnName): void
     {
-        $table = new Table('test_rename');
-        $table->addColumn($columnName, Types::STRING, ['length' => 16]);
-        $table->addColumn('c2', Types::INTEGER);
+        $table = Table::editor()
+            ->setUnquotedName('test_rename')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName($oldColumnName)
+                    ->setTypeName(Types::STRING)
+                    ->setLength(16)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('c2')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $this->dropAndCreateTable($table);
 
-        $table->dropColumn($columnName)
-            ->addColumn($newColumnName, Types::STRING, ['length' => 16]);
+        $table = $table->edit()
+            ->dropColumnByUnquotedName($oldColumnName)
+            ->addColumn(
+                Column::editor()
+                    ->setUnquotedName($newColumnName)
+                    ->setTypeName(Types::STRING)
+                    ->setLength(16)
+                    ->create(),
+            )
+            ->create();
 
         $sm   =  $this->connection->createSchemaManager();
         $diff = $sm->createComparator()
@@ -59,17 +82,34 @@ class RenameColumnTest extends FunctionalTestCase
         return $renamed;
     }
 
-    /** @dataProvider columnNameProvider */
-    public function testColumnPositionRetainedAfterExplicitRenaming(string $columnName, string $newColumnName): void
+    /**
+     * @param non-empty-string $oldColumnName
+     * @param non-empty-string $newColumnName
+     */
+    #[DataProvider('columnNameProvider')]
+    public function testColumnPositionRetainedAfterExplicitRenaming(string $oldColumnName, string $newColumnName): void
     {
-        $table = new Table('test_rename');
-        $table->addColumn($columnName, Types::INTEGER, ['length' => 16]);
-        $table->addColumn('c2', Types::INTEGER);
+        $table = Table::editor()
+            ->setUnquotedName('test_rename')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName($oldColumnName)
+                    ->setTypeName(Types::INTEGER)
+                    ->setLength(16)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('c2')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $this->dropAndCreateTable($table);
 
         // Force a different type to make sure it's not being caught implicitly
-        $table->renameColumn($columnName, $newColumnName)->setType(Type::getType(Types::BIGINT))->setLength(32);
+        $table->renameColumn($oldColumnName, $newColumnName)
+            ->setType(Type::getType(Types::BIGINT))
+            ->setLength(32);
 
         $sm   = $this->connection->createSchemaManager();
         $diff = $sm->createComparator()
@@ -88,7 +128,7 @@ class RenameColumnTest extends FunctionalTestCase
         self::assertEqualsIgnoringCase('c2', $columns[1]->getName());
     }
 
-    /** @return iterable<array{string,string}> */
+    /** @return iterable<array{non-empty-string,non-empty-string}> */
     public static function columnNameProvider(): iterable
     {
         yield ['c1', 'c1_x'];
@@ -99,13 +139,27 @@ class RenameColumnTest extends FunctionalTestCase
     /** @throws Exception */
     public function testRenameColumToQuoted(): void
     {
-        $table = new Table('test_rename');
-        $table->addColumn('c1', Types::INTEGER);
+        $table = Table::editor()
+            ->setUnquotedName('test_rename')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('c1')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $this->dropAndCreateTable($table);
 
-        $table->dropColumn('c1')
-            ->addColumn('"c2"', Types::INTEGER);
+        $table = $table->edit()
+            ->dropColumnByUnquotedName('c1')
+            ->addColumn(
+                Column::editor()
+                    ->setQuotedName('c2')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $schemaManager = $this->connection->createSchemaManager();
         $comparator    = $schemaManager->createComparator();
