@@ -7,7 +7,9 @@ namespace Doctrine\DBAL\Tests\Functional\Schema;
 use Doctrine\DBAL\Platforms\AbstractMySQLPlatform;
 use Doctrine\DBAL\Platforms\MariaDBPlatform;
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
+use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\Comparator;
+use Doctrine\DBAL\Schema\ComparatorConfig;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\Functional\Platform\RenameColumnTest;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
@@ -25,19 +27,27 @@ class ComparatorTest extends FunctionalTestCase
     }
 
     #[DataProvider('defaultValueProvider')]
-    public function testDefaultValueComparison(string $type, mixed $value): void
+    public function testDefaultValueComparison(string $typeName, mixed $value): void
     {
         $platform = $this->connection->getDatabasePlatform();
         if (
-            $type === Types::TEXT && $platform instanceof AbstractMySQLPlatform
+            $typeName === Types::TEXT && $platform instanceof AbstractMySQLPlatform
             && ! $platform instanceof MariaDBPlatform
         ) {
             // See https://dev.mysql.com/doc/relnotes/mysql/8.0/en/news-8-0-13.html#mysqld-8-0-13-data-types
             self::markTestSkipped('Oracle MySQL does not support default values on TEXT/BLOB columns until 8.0.13.');
         }
 
-        $table = new Table('default_value');
-        $table->addColumn('test', $type, ['default' => $value]);
+        $table = Table::editor()
+            ->setUnquotedName('default_value')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('test')
+                    ->setTypeName($typeName)
+                    ->setDefaultValue($value)
+                    ->create(),
+            )
+            ->create();
 
         $this->dropAndCreateTable($table);
 
@@ -53,12 +63,31 @@ class ComparatorTest extends FunctionalTestCase
     public function testRenameColumnComparison(): void
     {
         $platform   = $this->connection->getDatabasePlatform();
-        $comparator = new Comparator($platform);
+        $comparator = new Comparator($platform, new ComparatorConfig());
 
-        $table = new Table('rename_table');
-        $table->addColumn('test', Types::STRING, ['default' => 'baz', 'length' => 20]);
-        $table->addColumn('test2', Types::STRING, ['default' => 'baz', 'length' => 20]);
-        $table->addColumn('test3', Types::STRING, ['default' => 'foo', 'length' => 10]);
+        $table = Table::editor()
+            ->setUnquotedName('rename_table')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('test')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(20)
+                    ->setDefaultValue('baz')
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('test2')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(20)
+                    ->setDefaultValue('baz')
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('test3')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(10)
+                    ->setDefaultValue('foo')
+                    ->create(),
+            )
+            ->create();
 
         $onlineTable = clone $table;
         $table->renameColumn('test', 'baz')
