@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace Doctrine\DBAL\Tests\Functional\Schema;
 
+use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Types\Types;
@@ -15,17 +16,29 @@ class DefaultValueTest extends FunctionalTestCase
 {
     protected function setUp(): void
     {
-        $table = new Table('default_value');
-        $table->addColumn('id', Types::INTEGER);
+        $editor = Table::editor()
+            ->setUnquotedName('default_value')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            );
 
         foreach (self::columnProvider() as [$name, $default]) {
-            $table->addColumn($name, Types::STRING, [
-                'length' => 32,
-                'default' => $default,
-                'notnull' => false,
-            ]);
+            $editor->addColumn(
+                Column::editor()
+                    ->setUnquotedName($name)
+                    ->setTypeName(Types::STRING)
+                    ->setLength(32)
+                    ->setDefaultValue($default)
+                    ->setNotNull(false)
+                    ->create(),
+            );
         }
 
+        $table = $editor->create();
+
         $this->dropAndCreateTable($table);
 
         $this->connection->insert('default_value', ['id' => 1]);
