@@ -11,6 +11,7 @@ use Doctrine\DBAL\Platforms\MariaDBPlatform;
 use Doctrine\DBAL\Platforms\MySQL80Platform;
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
 use Doctrine\DBAL\Schema\Column;
+use Doctrine\DBAL\Schema\ColumnEditor;
 use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\Functional\Schema\ComparatorTestUtils;
@@ -42,7 +43,7 @@ final class ComparatorTest extends FunctionalTestCase
     public function testLobLengthIncrementWithinLimit(string $type, int $length): void
     {
         $table = $this->createLobTable($type, $length - 1);
-        $this->setBlobLength($table, $length);
+        $table = $this->setBlobLength($table, $length);
 
         self::assertTrue(ComparatorTestUtils::diffFromActualToDesiredTable(
             $this->schemaManager,
@@ -61,7 +62,7 @@ final class ComparatorTest extends FunctionalTestCase
     public function testLobLengthIncrementOverLimit(string $type, int $length): void
     {
         $table = $this->createLobTable($type, $length);
-        $this->setBlobLength($table, $length + 1);
+        $table = $this->setBlobLength($table, $length + 1);
         ComparatorTestUtils::assertDiffNotEmpty($this->connection, $this->comparator, $table);
     }
 
@@ -78,10 +79,18 @@ final class ComparatorTest extends FunctionalTestCase
     }
 
     /** @throws Exception */
-    private function createLobTable(string $type, int $length): Table
+    private function createLobTable(string $typeName, int $length): Table
     {
-        $table = new Table('comparator_test');
-        $table->addColumn('lob', $type)->setLength($length);
+        $table = Table::editor()
+            ->setUnquotedName('comparator_test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('lob')
+                    ->setTypeName($typeName)
+                    ->setLength($length)
+                    ->create(),
+            )
+            ->create();
 
         $this->dropAndCreateTable($table);
 
@@ -89,15 +98,23 @@ final class ComparatorTest extends FunctionalTestCase
     }
 
     /** @throws Exception */
-    private function setBlobLength(Table $table, int $length): void
+    private function setBlobLength(Table $table, int $length): Table
     {
-        $table->getColumn('lob')->setLength($length);
+        return $table->edit()
+            ->modifyColumnByUnquotedName('lob', static function (ColumnEditor $editor) use ($length): void {
+                $editor->setLength($length);
+            })
+            ->create();
     }
 
     public function testExplicitDefaultCollation(): void
     {
-        [$table, $column] = $this->createCollationTable();
-        $column->setPlatformOption('collation', 'utf8mb4_general_ci');
+        $table = $this->createCollationTable()
+            ->edit()
+            ->modifyColumnByUnquotedName('id', static function (ColumnEditor $editor): void {
+                $editor->setCollation('utf8mb4_general_ci');
+            })
+            ->create();
 
         self::assertTrue(ComparatorTestUtils::diffFromActualToDesiredTable(
             $this->schemaManager,
@@ -114,33 +131,54 @@ final class ComparatorTest extends FunctionalTestCase
 
     public function testChangeColumnCharsetAndCollation(): void
     {
-        [$table, $column] = $this->createCollationTable();
-        $column->setPlatformOption('charset', 'latin1');
-        $column->setPlatformOption('collation', 'latin1_bin');
+        $table = $this->createCollationTable()
+            ->edit()
+            ->modifyColumnByUnquotedName('id', static function (ColumnEditor $editor): void {
+                $editor
+                    ->setCharset('latin1')
+                    ->setCollation('latin1_bin');
+            })
+            ->create();
 
         ComparatorTestUtils::assertDiffNotEmpty($this->connection, $this->comparator, $table);
     }
 
     public function testChangeColumnCollation(): void
     {
-        [$table, $column] = $this->createCollationTable();
-        $column->setPlatformOption('collation', 'utf8mb4_bin');
+        $table = $this->createCollationTable()
+            ->edit()
+            ->modifyColumnByUnquotedName('id', static function (ColumnEditor $editor): void {
+                $editor->setCollation('utf8mb4_bin');
+            })
+            ->create();
 
         ComparatorTestUtils::assertDiffNotEmpty($this->connection, $this->comparator, $table);
     }
 
     /**
      * @param array<string,string> $tableOptions
-     * @param array<string,string> $columnOptions
+     * @param ?non-empty-string    $columnCharset
+     * @param ?non-empty-string    $columnCollation
      */
     #[DataProvider('tableAndColumnOptionsProvider')]
-    public function testTableAndColumnOptions(array $tableOptions, array $columnOptions): void
-    {
-        $table = new Table('comparator_test', [], [], [], [], $tableOptions);
-        $table->addColumn('name', Types::STRING, [
-            'length' => 32,
-            'platformOptions' => $columnOptions,
-        ]);
+    public function testTableAndColumnOptions(
+        array $tableOptions,
+        ?string $columnCharset,
+        ?string $columnCollation,
+    ): void {
+        $table = Table::editor()
+            ->setUnquotedName('comparator_test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('name')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(32)
+                    ->setCharset($columnCharset)
+                    ->setCollation($columnCollation)
+                    ->create(),
+            )
+            ->setOptions($tableOptions)
+            ->create();
 
         $this->dropAndCreateTable($table);
 
@@ -159,9 +197,17 @@ final class ComparatorTest extends FunctionalTestCase
 
     public function testSimpleArrayTypeNonChangeNotDetected(): void
     {
-        $table = new Table('comparator_test');
+        $table = Table::editor()
+            ->setUnquotedName('comparator_test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('simple_array_col')
+                    ->setTypeName(Types::SIMPLE_ARRAY)
+                    ->setLength(255)
+                    ->create(),
+            )
+            ->create();
 
-        $table->addColumn('simple_array_col', Types::SIMPLE_ARRAY, ['length' => 255]);
         $this->dropAndCreateTable($table);
 
         self::assertTrue(ComparatorTestUtils::diffFromActualToDesiredTable(
@@ -177,22 +223,25 @@ final class ComparatorTest extends FunctionalTestCase
         )->isEmpty());
     }
 
-    /** @return iterable<string,array{array<string,string>,array<string,string>}> */
+    /** @return iterable<string,array{array<string,string>,?non-empty-string,?non-empty-string}> */
     public static function tableAndColumnOptionsProvider(): iterable
     {
         yield "Column collation explicitly set to its table's default" => [
             [],
-            ['collation' => 'utf8mb4_unicode_ci'],
+            null,
+            'utf8mb4_general_ci',
         ];
 
         yield "Column charset implicitly set to a value matching its table's charset" => [
             ['charset' => 'utf8mb4'],
-            ['collation' => 'utf8mb4_unicode_ci'],
+            null,
+            'utf8mb4_general_ci',
         ];
 
         yield "Column collation reset to the collation's default matching its table's charset" => [
             ['collation' => 'utf8mb4_unicode_ci'],
-            ['charset' => 'utf8mb4'],
+            'utf8mb4',
+            null,
         ];
     }
 
@@ -202,9 +251,16 @@ final class ComparatorTest extends FunctionalTestCase
             self::markTestSkipped();
         }
 
-        $table = new Table('mariadb_json_upgrade');
+        $table = Table::editor()
+            ->setUnquotedName('mariadb_json_upgrade')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('json_col')
+                    ->setTypeName(Types::JSON)
+                    ->create(),
+            )
+            ->create();
 
-        $table->addColumn('json_col', Types::JSON);
         $this->dropAndCreateTable($table);
 
         // Revert column to old LONGTEXT declaration
@@ -214,19 +270,25 @@ final class ComparatorTest extends FunctionalTestCase
         ComparatorTestUtils::assertDiffNotEmpty($this->connection, $this->comparator, $table);
     }
 
-    /**
-     * @return array{Table,Column}
-     *
-     * @throws Exception
-     */
-    private function createCollationTable(): array
+    private function createCollationTable(): Table
     {
-        $table = new Table('comparator_test');
-        $table->addOption('charset', 'utf8mb4');
-        $table->addOption('collation', 'utf8mb4_general_ci');
-        $column = $table->addColumn('id', Types::STRING, ['length' => 32]);
+        $table = Table::editor()
+            ->setUnquotedName('comparator_test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(32)
+                    ->create(),
+            )
+            ->setOptions([
+                'charset'   => 'utf8mb4',
+                'collation' => 'utf8mb4_general_ci',
+            ])
+            ->create();
+
         $this->dropAndCreateTable($table);
 
-        return [$table, $column];
+        return $table;
     }
 }
