@@ -1,34 +1,26 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Schema\MySQL;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Types\Type;
 
-use function strtoupper;
-
 class PointType extends Type
 {
     /**
      * {@inheritDoc}
      */
-    public function getName()
+    public function getSQLDeclaration(array $column, AbstractPlatform $platform): string
     {
-        return 'point';
+        return 'POINT';
     }
 
     /**
      * {@inheritDoc}
      */
-    public function getSQLDeclaration(array $column, AbstractPlatform $platform)
-    {
-        return strtoupper($this->getName());
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    public function getMappedDatabaseTypes(AbstractPlatform $platform)
+    public function getMappedDatabaseTypes(AbstractPlatform $platform): array
     {
         return ['point'];
     }
