@@ -4,10 +4,10 @@ declare(strict_types=1);
 
 namespace Doctrine\DBAL\Tests\Functional\Schema\Types;
 
-final class Money
+final readonly class Money
 {
     public function __construct(
-        private readonly string $value,
+        private string $value,
     ) {
     }
 
