@@ -4,6 +4,8 @@ declare(strict_types=1);
 
 namespace Doctrine\DBAL\Tests\Functional\Types;
 
+use Doctrine\DBAL\Schema\Column;
+use Doctrine\DBAL\Schema\PrimaryKeyConstraint;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
@@ -20,10 +22,26 @@ class BigIntTypeTest extends FunctionalTestCase
     #[DataProvider('provideBigIntLiterals')]
     public function testSelectBigInt(string $sqlLiteral, int|string|null $expectedValue): void
     {
-        $table = new Table('bigint_type_test');
-        $table->addColumn('id', Types::SMALLINT, ['notnull' => true]);
-        $table->addColumn('my_integer', Types::BIGINT, ['notnull' => false]);
-        $table->setPrimaryKey(['id']);
+        $table = Table::editor()
+            ->setUnquotedName('bigint_type_test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::SMALLINT)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('my_integer')
+                    ->setTypeName(Types::BIGINT)
+                    ->setNotNull(false)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->create();
+
         $this->dropAndCreateTable($table);
 
         $this->connection->executeStatement(<<<SQL
@@ -59,10 +77,27 @@ class BigIntTypeTest extends FunctionalTestCase
             self::markTestSkipped('This test only works on MySQL/MariaDB.');
         }
 
-        $table = new Table('bigint_type_test');
-        $table->addColumn('id', Types::SMALLINT, ['notnull' => true]);
-        $table->addColumn('my_integer', Types::BIGINT, ['notnull' => false, 'unsigned' => true]);
-        $table->setPrimaryKey(['id']);
+        $table = Table::editor()
+            ->setUnquotedName('bigint_type_test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::SMALLINT)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('my_integer')
+                    ->setTypeName(Types::BIGINT)
+                    ->setNotNull(false)
+                    ->setUnsigned(true)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->create();
+
         $this->dropAndCreateTable($table);
 
         // Insert (2 ** 64) - 1
