@@ -10,7 +10,13 @@ use Doctrine\DBAL\Platforms\MySQL;
 use Doctrine\DBAL\Platforms\MySQL\CharsetMetadataProvider;
 use Doctrine\DBAL\Platforms\MySQL\CollationMetadataProvider;
 use Doctrine\DBAL\Platforms\MySQL\DefaultTableOptions;
+use Doctrine\DBAL\Schema\Column;
+use Doctrine\DBAL\Schema\ColumnEditor;
 use Doctrine\DBAL\Schema\Comparator;
+use Doctrine\DBAL\Schema\ComparatorConfig;
+use Doctrine\DBAL\Schema\Index;
+use Doctrine\DBAL\Schema\Index\IndexType;
+use Doctrine\DBAL\Schema\PrimaryKeyConstraint;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\TransactionIsolationLevel;
 use Doctrine\DBAL\Types\Types;
@@ -28,8 +34,15 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
 
     public function testGenerateMixedCaseTableCreate(): void
     {
-        $table = new Table('Foo');
-        $table->addColumn('Bar', Types::INTEGER);
+        $table = Table::editor()
+            ->setUnquotedName('Foo')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('Bar')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $sql = $this->platform->getCreateTableSQL($table);
         self::assertEquals(
@@ -41,7 +54,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
     public function getGenerateTableSql(): string
     {
         return 'CREATE TABLE test (id INT AUTO_INCREMENT NOT NULL, test VARCHAR(255) DEFAULT NULL, '
-            . 'PRIMARY KEY(id))';
+            . 'PRIMARY KEY (id))';
     }
 
     /** @return string[] */
@@ -136,15 +149,30 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
 
     public function testUniquePrimaryKey(): void
     {
-        $keyTable = new Table('foo');
-        $keyTable->addColumn('bar', Types::INTEGER);
-        $keyTable->addColumn('baz', Types::STRING, ['length' => 32]);
-        $keyTable->setPrimaryKey(['bar']);
-        $keyTable->addUniqueIndex(['baz']);
+        $oldTable = Table::editor()
+            ->setUnquotedName('foo')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('bar')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('baz')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(32)
+                    ->create(),
+            )
+            ->create();
 
-        $oldTable = new Table('foo');
-        $oldTable->addColumn('bar', Types::INTEGER);
-        $oldTable->addColumn('baz', Types::STRING, ['length' => 32]);
+        $keyTable = $oldTable->edit()
+            ->addPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('bar')
+                    ->create(),
+            )
+            ->create();
+
+        $keyTable->addUniqueIndex(['baz']);
 
         $diff = $this->createComparator()
             ->compareTables($oldTable, $keyTable);
@@ -180,7 +208,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
     protected function getQuotedColumnInPrimaryKeySQL(): array
     {
         return ['CREATE TABLE `quoted` (`create` VARCHAR(255) NOT NULL, '
-                . 'PRIMARY KEY(`create`))',
+                . 'PRIMARY KEY (`create`))',
         ];
     }
 
@@ -207,7 +235,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
     {
         return [
             'CREATE TABLE `quoted` (`create` VARCHAR(255) NOT NULL, foo VARCHAR(255) NOT NULL, '
-                . '`bar` VARCHAR(255) NOT NULL, INDEX IDX_22660D028FD6E0FB8C736521D79164E3 (`create`, foo, `bar`))',
+                . '`bar` VARCHAR(255) NOT NULL, INDEX IDX_22660D028FD6E0FB8C7365216D704F76 (`create`, foo, `bar`))',
             'ALTER TABLE `quoted` ADD CONSTRAINT FK_WITH_RESERVED_KEYWORD FOREIGN KEY (`create`, foo, `bar`)'
                 . ' REFERENCES `foreign` (`create`, bar, `foo-bar`)',
             'ALTER TABLE `quoted` ADD CONSTRAINT FK_WITH_NON_RESERVED_KEYWORD FOREIGN KEY (`create`, foo, `bar`)'
@@ -219,13 +247,23 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
 
     public function testCreateTableWithFulltextIndex(): void
     {
-        $table = new Table('fulltext_table');
-        $table->addOption('engine', 'MyISAM');
-        $table->addColumn('text', Types::TEXT);
-        $table->addIndex(['text'], 'fulltext_text');
-
-        $index = $table->getIndex('fulltext_text');
-        $index->addFlag('fulltext');
+        $table = Table::editor()
+            ->setUnquotedName('fulltext_table')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('text')
+                    ->setTypeName(Types::TEXT)
+                    ->create(),
+            )
+            ->setIndexes(
+                Index::editor()
+                    ->setUnquotedName('fulltext_text')
+                    ->setType(IndexType::FULLTEXT)
+                    ->setUnquotedColumnNames('text')
+                    ->create(),
+            )
+            ->setOptions(['engine' => 'MyISAM'])
+            ->create();
 
         $sql = $this->platform->getCreateTableSQL($table);
         self::assertEquals(
@@ -240,13 +278,24 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
 
     public function testCreateTableWithSpatialIndex(): void
     {
-        $table = new Table('spatial_table');
-        $table->addOption('engine', 'MyISAM');
-        $table->addColumn('point', Types::TEXT); // This should be a point type
-        $table->addIndex(['point'], 'spatial_text');
-
-        $index = $table->getIndex('spatial_text');
-        $index->addFlag('spatial');
+        $table = Table::editor()
+            ->setUnquotedName('spatial_table')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('point')
+                    // This should be a point type
+                    ->setTypeName(Types::TEXT)
+                    ->create(),
+            )
+            ->setIndexes(
+                Index::editor()
+                    ->setUnquotedName('spatial_text')
+                    ->setType(IndexType::SPATIAL)
+                    ->setUnquotedColumnNames('point')
+                    ->create(),
+            )
+            ->setOptions(['engine' => 'MyISAM'])
+            ->create();
 
         $sql = $this->platform->getCreateTableSQL($table);
         self::assertEquals(
@@ -347,11 +396,33 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
 
     public function testIgnoresDifferenceInDefaultValuesForUnsupportedColumnTypes(): void
     {
-        $table = new Table('text_blob_default_value');
-        $table->addColumn('def_text', Types::TEXT, ['default' => 'def']);
-        $table->addColumn('def_text_null', Types::TEXT, ['notnull' => false, 'default' => 'def']);
-        $table->addColumn('def_blob', Types::BLOB, ['default' => 'def']);
-        $table->addColumn('def_blob_null', Types::BLOB, ['notnull' => false, 'default' => 'def']);
+        $table = Table::editor()
+            ->setUnquotedName('text_blob_default_value')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('def_text')
+                    ->setTypeName(Types::TEXT)
+                    ->setDefaultValue('def')
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('def_text_null')
+                    ->setTypeName(Types::TEXT)
+                    ->setNotNull(false)
+                    ->setDefaultValue('def')
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('def_blob')
+                    ->setTypeName(Types::BLOB)
+                    ->setDefaultValue('def')
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('def_blob_null')
+                    ->setTypeName(Types::BLOB)
+                    ->setNotNull(false)
+                    ->setDefaultValue('def')
+                    ->create(),
+            )
+            ->create();
 
         self::assertSame(
             [
@@ -364,11 +435,20 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
             $this->platform->getCreateTableSQL($table),
         );
 
-        $diffTable = clone $table;
-        $diffTable->modifyColumn('def_text', ['default' => null]);
-        $diffTable->modifyColumn('def_text_null', ['default' => null]);
-        $diffTable->modifyColumn('def_blob', ['default' => null]);
-        $diffTable->modifyColumn('def_blob_null', ['default' => null]);
+        $diffTable = $table->edit()
+            ->modifyColumnByUnquotedName('def_text', static function (ColumnEditor $editor): void {
+                $editor->setDefaultValue(null);
+            })
+            ->modifyColumnByUnquotedName('def_text_null', static function (ColumnEditor $editor): void {
+                $editor->setDefaultValue(null);
+            })
+            ->modifyColumnByUnquotedName('def_blob', static function (ColumnEditor $editor): void {
+                $editor->setDefaultValue(null);
+            })
+            ->modifyColumnByUnquotedName('def_blob_null', static function (ColumnEditor $editor): void {
+                $editor->setDefaultValue(null);
+            })
+            ->create();
 
         $comparator = $this->createComparator();
 
@@ -500,10 +580,22 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
 
     public function testGetCreateTableSQLWithColumnCollation(): void
     {
-        $table = new Table('foo');
-        $table->addColumn('no_collation', Types::STRING, ['length' => 255]);
-        $table->addColumn('column_collation', Types::STRING, ['length' => 255])
-            ->setPlatformOption('collation', 'ascii_general_ci');
+        $table = Table::editor()
+            ->setUnquotedName('foo')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('no_collation')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('column_collation')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->setCollation('ascii_general_ci')
+                    ->create(),
+            )
+            ->create();
 
         self::assertSame(
             [
@@ -526,6 +618,7 @@ abstract class AbstractMySQLPlatformTestCase extends AbstractPlatformTestCase
             self::createStub(CharsetMetadataProvider::class),
             self::createStub(CollationMetadataProvider::class),
             new DefaultTableOptions('utf8mb4', 'utf8mb4_general_ci'),
+            new ComparatorConfig(),
         );
     }
 
