@@ -11,13 +11,19 @@ use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\ColumnDiff;
 use Doctrine\DBAL\Schema\Comparator;
+use Doctrine\DBAL\Schema\ComparatorConfig;
 use Doctrine\DBAL\Schema\ForeignKeyConstraint;
 use Doctrine\DBAL\Schema\Index;
+use Doctrine\DBAL\Schema\Name\Identifier;
+use Doctrine\DBAL\Schema\Name\OptionallyQualifiedName;
+use Doctrine\DBAL\Schema\Name\UnqualifiedName;
+use Doctrine\DBAL\Schema\PrimaryKeyConstraint;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\Schema\UniqueConstraint;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
+use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 use InvalidArgumentException;
 use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
@@ -28,6 +34,8 @@ use function sprintf;
 /** @template T of AbstractPlatform */
 abstract class AbstractPlatformTestCase extends TestCase
 {
+    use VerifyDeprecations;
+
     /** @var T */
     protected AbstractPlatform $platform;
 
@@ -41,7 +49,7 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     protected function createComparator(): Comparator
     {
-        return new Comparator($this->platform);
+        return new Comparator($this->platform, new ComparatorConfig());
     }
 
     public function testQuoteIdentifier(): void
@@ -136,10 +144,27 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testGeneratesTableCreationSql(): void
     {
-        $table = new Table('test');
-        $table->addColumn('id', Types::INTEGER, ['notnull' => true, 'autoincrement' => true]);
-        $table->addColumn('test', Types::STRING, ['notnull' => false, 'length' => 255]);
-        $table->setPrimaryKey(['id']);
+        $table = Table::editor()
+            ->setUnquotedName('test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->setAutoincrement(true)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('test')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->setNotNull(false)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->create();
 
         $sql = $this->platform->getCreateTableSQL($table);
         self::assertEquals($this->getGenerateTableSql(), $sql[0]);
@@ -149,9 +174,24 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testGenerateTableWithMultiColumnUniqueIndex(): void
     {
-        $table = new Table('test');
-        $table->addColumn('foo', Types::STRING, ['notnull' => false, 'length' => 255]);
-        $table->addColumn('bar', Types::STRING, ['notnull' => false, 'length' => 255]);
+        $table = Table::editor()
+            ->setUnquotedName('test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('foo')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->setNotNull(false)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('bar')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->setNotNull(false)
+                    ->create(),
+            )
+            ->create();
+
         $table->addUniqueIndex(['foo', 'bar']);
 
         $sql = $this->platform->getCreateTableSQL($table);
@@ -187,7 +227,10 @@ abstract class AbstractPlatformTestCase extends TestCase
     {
         $where            = 'test IS NULL AND test2 IS NOT NULL';
         $indexDef         = new Index('name', ['test', 'test2'], false, false, [], ['where' => $where]);
-        $uniqueConstraint = new UniqueConstraint('name', ['test', 'test2'], [], []);
+        $uniqueConstraint = UniqueConstraint::editor()
+            ->setUnquotedName('name')
+            ->setUnquotedColumnNames('test', 'test2')
+            ->create();
 
         $expected = ' WHERE ' . $where;
 
@@ -267,6 +310,7 @@ abstract class AbstractPlatformTestCase extends TestCase
     {
         self::assertEquals(
             'foo MEDIUMINT(6) UNSIGNED',
+            /** @phpstan-ignore argument.type */
             $this->platform->getColumnDeclarationSQL('foo', ['columnDefinition' => 'MEDIUMINT(6) UNSIGNED']),
         );
     }
@@ -336,9 +380,21 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testQuotedColumnInPrimaryKeyPropagation(): void
     {
-        $table = new Table('`quoted`');
-        $table->addColumn('create', Types::STRING, ['length' => 255]);
-        $table->setPrimaryKey(['create']);
+        $table = Table::editor()
+            ->setQuotedName('quoted')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('create')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('create')
+                    ->create(),
+            )
+            ->create();
 
         $sql = $this->platform->getCreateTableSQL($table);
         self::assertEquals($this->getQuotedColumnInPrimaryKeySQL(), $sql);
@@ -358,8 +414,17 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testQuotedColumnInIndexPropagation(): void
     {
-        $table = new Table('`quoted`');
-        $table->addColumn('create', Types::STRING, ['length' => 255]);
+        $table = Table::editor()
+            ->setQuotedName('quoted')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('create')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->create(),
+            )
+            ->create();
+
         $table->addIndex(['create']);
 
         $sql = $this->platform->getCreateTableSQL($table);
@@ -368,9 +433,22 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testQuotedNameInIndexSQL(): void
     {
-        $table = new Table('test');
-        $table->addColumn('column1', Types::STRING, ['length' => 255]);
-        $table->addIndex(['column1'], '`key`');
+        $table = Table::editor()
+            ->setUnquotedName('test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('column1')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->create(),
+            )
+            ->setIndexes(
+                Index::editor()
+                    ->setQuotedName('key')
+                    ->setUnquotedColumnNames('column1')
+                    ->create(),
+            )
+            ->create();
 
         $sql = $this->platform->getCreateTableSQL($table);
         self::assertEquals($this->getQuotedNameInIndexSQL(), $sql);
@@ -378,70 +456,58 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testQuotedColumnInForeignKeyPropagation(): void
     {
-        $table = new Table('`quoted`');
-        $table->addColumn('create', Types::STRING, ['length' => 255]);
-        $table->addColumn('foo', Types::STRING, ['length' => 255]);
-        $table->addColumn('`bar`', Types::STRING, ['length' => 255]);
+        $referencingColumnNames = [
+            UnqualifiedName::unquoted('create'),
+            UnqualifiedName::unquoted('foo'),
+            UnqualifiedName::quoted('bar'),
+        ];
 
-        // Foreign table with reserved keyword as name (needs quotation).
-        $foreignTable = new Table('foreign');
+        $referencedColumnNames = [
+            UnqualifiedName::unquoted('create'),
+            UnqualifiedName::unquoted('bar'),
+            UnqualifiedName::quoted('foo-bar'),
+        ];
 
-        // Foreign column with reserved keyword as name (needs quotation).
-        $foreignTable->addColumn('create', Types::STRING);
-
-        // Foreign column with non-reserved keyword as name (does not need quotation).
-        $foreignTable->addColumn('bar', Types::STRING);
-
-        // Foreign table with special character in name (needs quotation on some platforms, e.g. Sqlite).
-        $foreignTable->addColumn('`foo-bar`', Types::STRING);
-
-        $table->addForeignKeyConstraint(
-            $foreignTable->getQuotedName($this->platform),
-            ['create', 'foo', '`bar`'],
-            ['create', 'bar', '`foo-bar`'],
-            [],
-            'FK_WITH_RESERVED_KEYWORD',
-        );
-
-        // Foreign table with non-reserved keyword as name (does not need quotation).
-        $foreignTable = new Table('foo');
-
-        // Foreign column with reserved keyword as name (needs quotation).
-        $foreignTable->addColumn('create', Types::STRING);
-
-        // Foreign column with non-reserved keyword as name (does not need quotation).
-        $foreignTable->addColumn('bar', Types::STRING);
-
-        // Foreign table with special character in name (needs quotation on some platforms, e.g. Sqlite).
-        $foreignTable->addColumn('`foo-bar`', Types::STRING);
-
-        $table->addForeignKeyConstraint(
-            $foreignTable->getQuotedName($this->platform),
-            ['create', 'foo', '`bar`'],
-            ['create', 'bar', '`foo-bar`'],
-            [],
-            'FK_WITH_NON_RESERVED_KEYWORD',
-        );
-
-        // Foreign table with special character in name (needs quotation on some platforms, e.g. Sqlite).
-        $foreignTable = new Table('`foo-bar`');
-
-        // Foreign column with reserved keyword as name (needs quotation).
-        $foreignTable->addColumn('create', Types::STRING);
-
-        // Foreign column with non-reserved keyword as name (does not need quotation).
-        $foreignTable->addColumn('bar', Types::STRING);
-
-        // Foreign table with special character in name (needs quotation on some platforms, e.g. Sqlite).
-        $foreignTable->addColumn('`foo-bar`', Types::STRING);
-
-        $table->addForeignKeyConstraint(
-            $foreignTable->getQuotedName($this->platform),
-            ['create', 'foo', '`bar`'],
-            ['create', 'bar', '`foo-bar`'],
-            [],
-            'FK_WITH_INTENDED_QUOTATION',
-        );
+        $table = Table::editor()
+            ->setQuotedName('quoted')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('create')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('foo')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->create(),
+                Column::editor()
+                    ->setQuotedName('bar')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->create(),
+            )
+            ->setForeignKeyConstraints(
+                ForeignKeyConstraint::editor()
+                    ->setUnquotedName('FK_WITH_RESERVED_KEYWORD')
+                    ->setReferencingColumnNames(...$referencingColumnNames)
+                    ->setUnquotedReferencedTableName('foreign')
+                    ->setReferencedColumnNames(...$referencedColumnNames)
+                    ->create(),
+                ForeignKeyConstraint::editor()
+                    ->setUnquotedName('FK_WITH_NON_RESERVED_KEYWORD')
+                    ->setReferencingColumnNames(...$referencingColumnNames)
+                    ->setUnquotedReferencedTableName('foo')
+                    ->setReferencedColumnNames(...$referencedColumnNames)
+                    ->create(),
+                ForeignKeyConstraint::editor()
+                    ->setUnquotedName('FK_WITH_INTENDED_QUOTATION')
+                    ->setReferencingColumnNames(...$referencingColumnNames)
+                    ->setQuotedReferencedTableName('foo-bar')
+                    ->setReferencedColumnNames(...$referencedColumnNames)
+                    ->create(),
+            )
+            ->create();
 
         $sql = $this->platform->getCreateTableSQL($table);
         self::assertEquals($this->getQuotedColumnInForeignKeySQL(), $sql);
@@ -509,22 +575,29 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testAlterTableChangeQuotedColumn(): void
     {
-        $table = new Table('mytable');
-        $table->addColumn('select', Types::INTEGER);
+        $table = Table::editor()
+            ->setUnquotedName('mytable')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('select')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($table, changedColumns: [
             'select' => new ColumnDiff(
                 $table->getColumn('select'),
-                new Column(
-                    'select',
-                    Type::getType(Types::STRING),
-                    ['length' => 255],
-                ),
+                Column::editor()
+                    ->setUnquotedName('select')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->create(),
             ),
         ]);
 
         self::assertStringContainsString(
-            $this->platform->quoteIdentifier('select'),
+            $this->platform->quoteSingleIdentifier('select'),
             implode(';', $this->platform->getAlterTableSQL($tableDiff)),
         );
     }
@@ -665,11 +738,32 @@ abstract class AbstractPlatformTestCase extends TestCase
         );
     }
 
+    public function testReturnsJsonbTypeDeclarationSQL(): void
+    {
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6939');
+
+        self::assertSame(
+            $this->platform->getJsonTypeDeclarationSQL(['jsonb' => true]),
+            $this->platform->getJsonbTypeDeclarationSQL([]),
+        );
+    }
+
     public function testAlterTableRenameIndex(): void
     {
-        $table = new Table('mytable');
-        $table->addColumn('id', Types::INTEGER);
-        $table->setPrimaryKey(['id']);
+        $table = Table::editor()
+            ->setUnquotedName('mytable')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($table, renamedIndexes: [
             'idx_foo' => new Index('idx_bar', ['id']),
@@ -692,9 +786,20 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testQuotesAlterTableRenameIndex(): void
     {
-        $table = new Table('table');
-        $table->addColumn('id', Types::INTEGER);
-        $table->setPrimaryKey(['id']);
+        $table = Table::editor()
+            ->setUnquotedName('table')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($table, renamedIndexes: [
             'create' => new Index('select', ['id']),
@@ -720,9 +825,20 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testAlterTableRenameIndexInSchema(): void
     {
-        $table = new Table('myschema.mytable');
-        $table->addColumn('id', Types::INTEGER);
-        $table->setPrimaryKey(['id']);
+        $table = Table::editor()
+            ->setUnquotedName('mytable', 'myschema')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($table, renamedIndexes: ['idx_foo' => new Index('idx_bar', ['id'])]);
 
@@ -743,9 +859,25 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testQuotesAlterTableRenameIndexInSchema(): void
     {
-        $table = new Table('`schema`.table');
-        $table->addColumn('id', Types::INTEGER);
-        $table->setPrimaryKey(['id']);
+        $table = Table::editor()
+            ->setName(
+                new OptionallyQualifiedName(
+                    Identifier::unquoted('table'),
+                    Identifier::quoted('schema'),
+                ),
+            )
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($table, renamedIndexes: [
             'create' => new Index('select', ['id']),
@@ -891,17 +1023,26 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testAlterStringToFixedString(): void
     {
-        $table = new Table('mytable');
-        $table->addColumn('name', Types::STRING, ['length' => 2]);
+        $table = Table::editor()
+            ->setUnquotedName('mytable')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('name')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(2)
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($table, changedColumns: [
             'name' => new ColumnDiff(
                 $table->getColumn('name'),
-                new Column(
-                    'name',
-                    Type::getType(Types::STRING),
-                    ['fixed' => true, 'length' => 2],
-                ),
+                Column::editor()
+                    ->setUnquotedName('name')
+                    ->setTypeName(Types::STRING)
+                    ->setFixed(true)
+                    ->setLength(2)
+                    ->create(),
             ),
         ]);
 
@@ -917,18 +1058,47 @@ abstract class AbstractPlatformTestCase extends TestCase
 
     public function testGeneratesAlterTableRenameIndexUsedByForeignKeySQL(): void
     {
-        $foreignTable = new Table('foreign_table');
-        $foreignTable->addColumn('id', Types::INTEGER);
-        $foreignTable->setPrimaryKey(['id']);
-
-        $primaryTable = new Table('mytable');
-        $primaryTable->addColumn('foo', Types::INTEGER);
-        $primaryTable->addColumn('bar', Types::INTEGER);
-        $primaryTable->addColumn('baz', Types::INTEGER);
-        $primaryTable->addIndex(['foo'], 'idx_foo');
-        $primaryTable->addIndex(['bar'], 'idx_bar');
-        $primaryTable->addForeignKeyConstraint($foreignTable->getName(), ['foo'], ['id'], [], 'fk_foo');
-        $primaryTable->addForeignKeyConstraint($foreignTable->getName(), ['bar'], ['id'], [], 'fk_bar');
+        $primaryTable = Table::editor()
+            ->setUnquotedName('mytable')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('foo')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('bar')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('baz')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->setIndexes(
+                Index::editor()
+                    ->setUnquotedName('idx_foo')
+                    ->setUnquotedColumnNames('foo')
+                    ->create(),
+                Index::editor()
+                    ->setUnquotedName('idx_bar')
+                    ->setUnquotedColumnNames('bar')
+                    ->create(),
+            )
+            ->setForeignKeyConstraints(
+                ForeignKeyConstraint::editor()
+                    ->setUnquotedName('fk_foo')
+                    ->setUnquotedReferencingColumnNames('foo')
+                    ->setUnquotedReferencedTableName('foreign_table')
+                    ->setUnquotedReferencedColumnNames('id')
+                    ->create(),
+                ForeignKeyConstraint::editor()
+                    ->setUnquotedName('fk_bar')
+                    ->setUnquotedReferencingColumnNames('bar')
+                    ->setUnquotedReferencedTableName('foreign_table')
+                    ->setUnquotedReferencedColumnNames('id')
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($primaryTable, renamedIndexes: [
             'idx_foo' => new Index('idx_foo_renamed', ['foo']),
