@@ -5,10 +5,9 @@ declare(strict_types=1);
 namespace Doctrine\DBAL\Tests\Platforms;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
-use Doctrine\DBAL\Platforms\Keywords\KeywordList;
 use Doctrine\DBAL\Platforms\MySQL84Platform;
 
-class MySQL84PlatformTest extends MySQL57PlatformTest
+class MySQL84PlatformTest extends MySQLPlatformTest
 {
     public function createPlatform(): AbstractPlatform
     {
@@ -18,7 +17,6 @@ class MySQL84PlatformTest extends MySQL57PlatformTest
     public function testMySQL84KeywordList(): void
     {
         $keywordList = $this->platform->getReservedKeywordsList();
-        self::assertInstanceOf(KeywordList::class, $keywordList);
 
         self::assertTrue($keywordList->isKeyword('persist'));
         self::assertTrue($keywordList->isKeyword('manual'));
