@@ -13,7 +13,6 @@ use Doctrine\DBAL\Schema\ForeignKeyConstraint;
 use Doctrine\DBAL\Schema\Sequence;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\TransactionIsolationLevel;
-use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
 use PHPUnit\Framework\Attributes\DataProvider;
 
@@ -31,7 +30,7 @@ class OraclePlatformTest extends AbstractPlatformTestCase
 
     public function getGenerateTableSql(): string
     {
-        return 'CREATE TABLE test (id NUMBER(10) NOT NULL, test VARCHAR2(255) DEFAULT NULL NULL, PRIMARY KEY(id))';
+        return 'CREATE TABLE test (id NUMBER(10) NOT NULL, test VARCHAR2(255) DEFAULT NULL NULL, PRIMARY KEY (id))';
     }
 
     /**
@@ -183,23 +182,29 @@ class OraclePlatformTest extends AbstractPlatformTestCase
     {
         $columnName = strtoupper('id' . uniqid());
         $tableName  = strtoupper('table' . uniqid());
-        $table      = new Table($tableName);
-
-        $column = $table->addColumn($columnName, Types::INTEGER);
-        $column->setAutoincrement(true);
+        $table      = Table::editor()
+            ->setUnquotedName($tableName)
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName($columnName)
+                    ->setTypeName(Types::INTEGER)
+                    ->setAutoincrement(true)
+                    ->create(),
+            )
+            ->create();
 
         self::assertSame([
             sprintf('CREATE TABLE %s (%s NUMBER(10) NOT NULL)', $tableName, $columnName),
             sprintf(
                 <<<'SQL'
 DECLARE
-  constraints_Count NUMBER;
+  CONSTRAINTS_COUNT NUMBER;
 BEGIN
-  SELECT COUNT(CONSTRAINT_NAME) INTO constraints_Count
+  SELECT COUNT(CONSTRAINT_NAME) INTO CONSTRAINTS_COUNT
     FROM USER_CONSTRAINTS
    WHERE TABLE_NAME = '%s'
      AND CONSTRAINT_TYPE = 'P';
-  IF constraints_Count = 0 OR constraints_Count = '' THEN
+  IF CONSTRAINTS_COUNT = 0 THEN
     EXECUTE IMMEDIATE 'ALTER TABLE %s ADD CONSTRAINT %s_AI_PK PRIMARY KEY (%s)';
   END IF;
 END;
@@ -225,7 +230,7 @@ BEGIN
       SELECT %s_SEQ.NEXTVAL INTO :NEW.%s FROM DUAL;
    ELSE
       SELECT NVL(Last_Number, 0) INTO last_Sequence
-        FROM User_Sequences
+        FROM USER_SEQUENCES
        WHERE Sequence_Name = '%s_SEQ';
       SELECT :NEW.%s INTO last_InsertID FROM DUAL;
       WHILE (last_InsertID > last_Sequence) LOOP
@@ -265,7 +270,7 @@ SQL
      */
     protected function getQuotedColumnInPrimaryKeySQL(): array
     {
-        return ['CREATE TABLE "quoted" ("create" VARCHAR2(255) NOT NULL, PRIMARY KEY("create"))'];
+        return ['CREATE TABLE "quoted" ("create" VARCHAR2(255) NOT NULL, PRIMARY KEY ("create"))'];
     }
 
     /**
@@ -304,7 +309,7 @@ SQL
                 . ' REFERENCES foo ("create", bar, "foo-bar")',
             'ALTER TABLE "quoted" ADD CONSTRAINT FK_WITH_INTENDED_QUOTATION FOREIGN KEY ("create", foo, "bar")'
                 . ' REFERENCES "foo-bar" ("create", bar, "foo-bar")',
-            'CREATE INDEX IDX_22660D028FD6E0FB8C736521D79164E3 ON "quoted" ("create", foo, "bar")',
+            'CREATE INDEX IDX_22660D028FD6E0FB8C7365216D704F76 ON "quoted" ("create", foo, "bar")',
         ];
     }
 
@@ -361,19 +366,39 @@ SQL
 
     public function testDoesNotPropagateUnnecessaryTableAlterationOnBinaryType(): void
     {
-        $table1 = new Table('mytable');
-        $table1->addColumn('column_varbinary', Types::BINARY, ['length' => 32]);
-        $table1->addColumn('column_binary', Types::BINARY, [
-            'fixed' => true,
-            'length' => 32,
-        ]);
+        $table1 = Table::editor()
+            ->setUnquotedName('mytable')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('column_varbinary')
+                    ->setTypeName(Types::BINARY)
+                    ->setLength(32)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('column_binary')
+                    ->setTypeName(Types::BINARY)
+                    ->setFixed(true)
+                    ->setLength(32)
+                    ->create(),
+            )
+            ->create();
 
-        $table2 = new Table('mytable');
-        $table2->addColumn('column_varbinary', Types::BINARY, [
-            'fixed' => true,
-            'length' => 32,
-        ]);
-        $table2->addColumn('column_binary', Types::BINARY, ['length' => 32]);
+        $table2 = Table::editor()
+            ->setUnquotedName('mytable')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('column_varbinary')
+                    ->setTypeName(Types::BINARY)
+                    ->setFixed(true)
+                    ->setLength(32)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('column_binary')
+                    ->setTypeName(Types::BINARY)
+                    ->setLength(32)
+                    ->create(),
+            )
+            ->create();
 
         self::assertTrue(
             $this->createComparator()
@@ -494,24 +519,49 @@ SQL
 
     public function testAltersTableColumnCommentWithExplicitlyQuotedIdentifiers(): void
     {
-        $table1 = new Table('"foo"', [new Column('"bar"', Type::getType(Types::INTEGER))]);
-        $table2 = new Table('"foo"', [new Column('"bar"', Type::getType(Types::INTEGER), ['comment' => 'baz'])]);
+        $table1 = Table::editor()
+            ->setQuotedName('Foo')
+            ->setColumns(
+                Column::editor()
+                    ->setQuotedName('Bar')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
+
+        $table2 = Table::editor()
+            ->setQuotedName('Foo')
+            ->setColumns(
+                Column::editor()
+                    ->setQuotedName('Bar')
+                    ->setTypeName(Types::INTEGER)
+                    ->setComment('Baz')
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = $this->createComparator()
             ->compareTables($table1, $table2);
 
         self::assertSame(
-            ['COMMENT ON COLUMN "foo"."bar" IS \'baz\''],
+            ['COMMENT ON COLUMN "Foo"."Bar" IS \'Baz\''],
             $this->platform->getAlterTableSQL($tableDiff),
         );
     }
 
     public function testQuotedTableNames(): void
     {
-        $table = new Table('"test"');
-        $table->addColumn('"id"', Types::INTEGER, ['autoincrement' => true]);
+        $table = Table::editor()
+            ->setQuotedName('test')
+            ->setColumns(
+                Column::editor()
+                    ->setQuotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->setAutoincrement(true)
+                    ->create(),
+            )
+            ->create();
 
-        // assert tabel
         self::assertTrue($table->isQuoted());
         self::assertEquals('test', $table->getName());
         self::assertEquals('"test"', $table->getQuotedName($this->platform));
@@ -532,7 +582,7 @@ BEGIN
       SELECT "test_SEQ".NEXTVAL INTO :NEW."id" FROM DUAL;
    ELSE
       SELECT NVL(Last_Number, 0) INTO last_Sequence
-        FROM User_Sequences
+        FROM USER_SEQUENCES
        WHERE Sequence_Name = 'test_SEQ';
       SELECT :NEW."id" INTO last_InsertID FROM DUAL;
       WHILE (last_InsertID > last_Sequence) LOOP
