@@ -13,7 +13,9 @@ use Doctrine\DBAL\Platforms\SQLServerPlatform;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\ColumnDiff;
 use Doctrine\DBAL\Schema\Comparator;
+use Doctrine\DBAL\Schema\ComparatorConfig;
 use Doctrine\DBAL\Schema\Index;
+use Doctrine\DBAL\Schema\PrimaryKeyConstraint;
 use Doctrine\DBAL\Schema\Sequence;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Schema\TableDiff;
@@ -32,7 +34,7 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
 
     protected function createComparator(): Comparator
     {
-        return new SQLServer\Comparator($this->platform, '');
+        return new SQLServer\Comparator($this->platform, '', new ComparatorConfig());
     }
 
     public function getGenerateTableSql(): string
@@ -566,10 +568,21 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
 
     public function testCreateNonClusteredPrimaryKeyInTable(): void
     {
-        $table = new Table('tbl');
-        $table->addColumn('id', Types::INTEGER);
-        $table->setPrimaryKey(['id']);
-        $table->getIndex('primary')->addFlag('nonclustered');
+        $table = Table::editor()
+            ->setUnquotedName('tbl')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->setIsClustered(false)
+                    ->create(),
+            )
+            ->create();
 
         self::assertEquals(
             ['CREATE TABLE tbl (id INT NOT NULL, PRIMARY KEY NONCLUSTERED (id))'],
@@ -631,7 +644,7 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
         return [
             'CREATE TABLE [quoted] ([create] NVARCHAR(255) NOT NULL, '
                 . 'foo NVARCHAR(255) NOT NULL, [bar] NVARCHAR(255) NOT NULL)',
-            'CREATE INDEX IDX_22660D028FD6E0FB8C736521D79164E3 ON [quoted] ([create], foo, [bar])',
+            'CREATE INDEX IDX_22660D028FD6E0FB8C7365216D704F76 ON [quoted] ([create], foo, [bar])',
             'ALTER TABLE [quoted] ADD CONSTRAINT FK_WITH_RESERVED_KEYWORD'
                 . ' FOREIGN KEY ([create], foo, [bar]) REFERENCES [foreign] ([create], bar, [foo-bar])',
             'ALTER TABLE [quoted] ADD CONSTRAINT FK_WITH_NON_RESERVED_KEYWORD'
@@ -650,13 +663,25 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
 
     public function testCreateTableWithSchemaColumnComments(): void
     {
-        $table = new Table('testschema.test');
-        $table->addColumn('id', Types::INTEGER, ['comment' => 'This is a comment']);
-        $table->setPrimaryKey(['id']);
+        $table = Table::editor()
+            ->setUnquotedName('test', 'testschema')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->setComment('This is a comment')
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->create();
 
         $expectedSql = [
             'CREATE TABLE testschema.test (id INT NOT NULL, PRIMARY KEY (id))',
-            "EXEC sp_addextendedproperty N'MS_Description', N'This is a comment', "
+            "EXEC [sp_addextendedproperty] N'MS_Description', N'This is a comment', "
                 . "N'SCHEMA', 'testschema', N'TABLE', 'test', N'COLUMN', 'id'",
         ];
 
@@ -665,19 +690,26 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
 
     public function testAlterTableWithSchemaColumnComments(): void
     {
-        $table = new Table('testschema.mytable');
+        $table = Table::editor()
+            ->setUnquotedName('mytable', 'testschema')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
-        $tableDiff = new TableDiff($table, addedColumns: [
-            new Column(
-                'quota',
-                Type::getType(Types::INTEGER),
-                ['comment' => 'A comment'],
-            ),
+        $tableDiff = new TableDiff($table, addedColumns: [Column::editor()
+                ->setUnquotedName('quota')
+                ->setTypeName(Types::INTEGER)
+                ->setComment('A comment')
+                ->create(),
         ]);
 
         $expectedSql = [
             'ALTER TABLE testschema.mytable ADD quota INT NOT NULL',
-            "EXEC sp_addextendedproperty N'MS_Description', N'A comment', "
+            "EXEC [sp_addextendedproperty] N'MS_Description', N'A comment', "
                 . "N'SCHEMA', 'testschema', N'TABLE', 'mytable', N'COLUMN', 'quota'",
         ];
 
@@ -686,17 +718,32 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
 
     public function testAlterTableWithSchemaDropColumnComments(): void
     {
-        $table = new Table('testschema.mytable');
+        $table = Table::editor()
+            ->setUnquotedName('mytable', 'testschema')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($table, changedColumns: [
             'quota' => new ColumnDiff(
-                new Column('quota', Type::getType(Types::INTEGER), ['comment' => 'A comment']),
-                new Column('quota', Type::getType(Types::INTEGER), []),
+                Column::editor()
+                    ->setUnquotedName('quota')
+                    ->setTypeName(Types::INTEGER)
+                    ->setComment('A comment')
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('quota')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
             ),
         ]);
 
         $expectedSql = [
-            "EXEC sp_dropextendedproperty N'MS_Description'"
+            "EXEC [sp_dropextendedproperty] N'MS_Description'"
                 . ", N'SCHEMA', 'testschema', N'TABLE', 'mytable', N'COLUMN', 'quota'",
         ];
 
@@ -705,16 +752,32 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
 
     public function testAlterTableWithSchemaUpdateColumnComments(): void
     {
-        $table = new Table('testschema.mytable');
+        $table = Table::editor()
+            ->setUnquotedName('mytable', 'testschema')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($table, changedColumns: [
             'quota' => new ColumnDiff(
-                new Column('quota', Type::getType(Types::INTEGER), ['comment' => 'A comment']),
-                new Column('quota', Type::getType(Types::INTEGER), ['comment' => 'B comment']),
+                Column::editor()
+                    ->setUnquotedName('quota')
+                    ->setTypeName(Types::INTEGER)
+                    ->setComment('A comment')
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('quota')
+                    ->setTypeName(Types::INTEGER)
+                    ->setComment('B comment')
+                    ->create(),
             ),
         ]);
 
-        $expectedSql = ["EXEC sp_updateextendedproperty N'MS_Description', N'B comment', "
+        $expectedSql = ["EXEC [sp_updateextendedproperty] N'MS_Description', N'B comment', "
                 . "N'SCHEMA', 'testschema', N'TABLE', 'mytable', N'COLUMN', 'quota'",
         ];
 
@@ -839,7 +902,7 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
      */
     protected function getAlterTableRenameIndexSQL(): array
     {
-        return ["EXEC sp_rename N'mytable.idx_foo', N'idx_bar', N'INDEX'"];
+        return ["EXEC [sp_rename] N'mytable.idx_foo', N'idx_bar', N'INDEX'"];
     }
 
     /**
@@ -848,8 +911,8 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
     protected function getQuotedAlterTableRenameIndexSQL(): array
     {
         return [
-            "EXEC sp_rename N'[table].[create]', N'select', N'INDEX'",
-            "EXEC sp_rename N'[table].[foo]', N'bar', N'INDEX'",
+            "EXEC [sp_rename] N'[table].[create]', N'select', N'INDEX'",
+            "EXEC [sp_rename] N'[table].[foo]', N'bar', N'INDEX'",
         ];
     }
 
@@ -858,7 +921,7 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
      */
     protected function getAlterTableRenameIndexInSchemaSQL(): array
     {
-        return ["EXEC sp_rename N'myschema.mytable.idx_foo', N'idx_bar', N'INDEX'"];
+        return ["EXEC [sp_rename] N'myschema.mytable.idx_foo', N'idx_bar', N'INDEX'"];
     }
 
     /**
@@ -867,8 +930,8 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
     protected function getQuotedAlterTableRenameIndexInSchemaSQL(): array
     {
         return [
-            "EXEC sp_rename N'[schema].[table].[create]', N'select', N'INDEX'",
-            "EXEC sp_rename N'[schema].[table].[foo]', N'bar', N'INDEX'",
+            "EXEC [sp_rename] N'[schema].[table].[create]', N'select', N'INDEX'",
+            "EXEC [sp_rename] N'[schema].[table].[foo]', N'bar', N'INDEX'",
         ];
     }
 
@@ -932,7 +995,7 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
      */
     protected function getGeneratesAlterTableRenameIndexUsedByForeignKeySQL(): array
     {
-        return ["EXEC sp_rename N'mytable.idx_foo', N'idx_foo_renamed', N'INDEX'"];
+        return ["EXEC [sp_rename] N'mytable.idx_foo', N'idx_foo_renamed', N'INDEX'"];
     }
 
     protected function getLimitOffsetCastToIntExpectedQuery(): string
@@ -1045,10 +1108,22 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
 
     public function testGetCreateTableSQLWithColumnCollation(): void
     {
-        $table = new Table('foo');
-        $table->addColumn('no_collation', Types::STRING, ['length' => 255]);
-        $table->addColumn('column_collation', Types::STRING, ['length' => 255])
-            ->setPlatformOption('collation', 'Latin1_General_CS_AS_KS_WS');
+        $table = Table::editor()
+            ->setUnquotedName('foo')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('no_collation')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('column_collation')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->setCollation('Latin1_General_CS_AS_KS_WS')
+                    ->create(),
+            )
+            ->create();
 
         self::assertSame(
             ['CREATE TABLE foo (no_collation NVARCHAR(255) NOT NULL, '
@@ -1086,12 +1161,29 @@ class SQLServerPlatformTest extends AbstractPlatformTestCase
 
     public function testAlterTableWithSchemaSameColumnComments(): void
     {
-        $table = new Table('testschema.mytable');
+        $table = Table::editor()
+            ->setUnquotedName('mytable', 'testschema')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($table, changedColumns: [
             'quota' => new ColumnDiff(
-                new Column('quota', Type::getType(Types::INTEGER), ['comment' => 'A comment', 'notnull' => false]),
-                new Column('quota', Type::getType(Types::INTEGER), ['comment' => 'A comment', 'notnull' => true]),
+                Column::editor()
+                    ->setUnquotedName('quota')
+                    ->setTypeName(Types::INTEGER)
+                    ->setComment('A comment')
+                    ->setNotNull(false)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('quota')
+                    ->setTypeName(Types::INTEGER)
+                    ->setComment('A comment')
+                    ->create(),
             ),
         ]);
 
