@@ -11,18 +11,24 @@ use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\ColumnDiff;
 use Doctrine\DBAL\Schema\Comparator;
+use Doctrine\DBAL\Schema\ComparatorConfig;
+use Doctrine\DBAL\Schema\ForeignKeyConstraint;
+use Doctrine\DBAL\Schema\ForeignKeyConstraint\Deferrability;
 use Doctrine\DBAL\Schema\Index;
+use Doctrine\DBAL\Schema\PrimaryKeyConstraint;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\TransactionIsolationLevel;
-use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
+use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 
 use function implode;
 
 /** @extends AbstractPlatformTestCase<SQLitePlatform> */
 class SQLitePlatformTest extends AbstractPlatformTestCase
 {
+    use VerifyDeprecations;
+
     public function createPlatform(): AbstractPlatform
     {
         return new SQLitePlatform();
@@ -30,7 +36,7 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
 
     protected function createComparator(): Comparator
     {
-        return new SQLite\Comparator($this->platform);
+        return new SQLite\Comparator($this->platform, new ComparatorConfig());
     }
 
     public function getGenerateTableSql(): string
@@ -238,9 +244,21 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
 
     public function testGenerateTableSqlShouldNotAutoQuotePrimaryKey(): void
     {
-        $table = new Table('test');
-        $table->addColumn('"like"', Types::INTEGER, ['notnull' => true, 'autoincrement' => true]);
-        $table->setPrimaryKey(['"like"']);
+        $table = Table::editor()
+            ->setUnquotedName('test')
+            ->setColumns(
+                Column::editor()
+                    ->setQuotedName('like')
+                    ->setTypeName(Types::INTEGER)
+                    ->setAutoincrement(true)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setQuotedColumnNames('like')
+                    ->create(),
+            )
+            ->create();
 
         $createTableSQL = $this->platform->getCreateTableSQL($table);
         self::assertEquals(
@@ -251,14 +269,27 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
 
     public function testAlterTableAddColumns(): void
     {
-        $table = new Table('user');
+        $table = Table::editor()
+            ->setUnquotedName('user')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $diff = new TableDiff($table, addedColumns: [
-            new Column('foo', Type::getType(Types::STRING)),
-            new Column('count', Type::getType(Types::INTEGER), [
-                'notnull' => false,
-                'default' => 1,
-            ]),
+            Column::editor()
+                ->setUnquotedName('foo')
+                ->setTypeName(Types::STRING)
+                ->create(),
+            Column::editor()
+                ->setUnquotedName('count')
+                ->setTypeName(Types::INTEGER)
+                ->setNotNull(false)
+                ->setDefaultValue(1)
+                ->create(),
         ]);
 
         $expected = [
@@ -271,13 +302,26 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
 
     public function testRenameNonExistingColumn(): void
     {
-        $table = new Table('test');
-        $table->addColumn('id', Types::INTEGER);
+        $table = Table::editor()
+            ->setUnquotedName('test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($table, changedColumns: [
             'value' => new ColumnDiff(
-                new Column('data', Type::getType(Types::STRING)),
-                new Column('value', Type::getType(Types::STRING)),
+                Column::editor()
+                    ->setUnquotedName('data')
+                    ->setTypeName(Types::STRING)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('value')
+                    ->setTypeName(Types::STRING)
+                    ->create(),
             ),
         ]);
 
@@ -287,25 +331,62 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
 
     public function testCreateTableWithDeferredForeignKeys(): void
     {
-        $table = new Table('user');
-        $table->addColumn('id', Types::INTEGER);
-        $table->addColumn('article', Types::INTEGER);
-        $table->addColumn('post', Types::INTEGER);
-        $table->addColumn('parent', Types::INTEGER);
-        $table->setPrimaryKey(['id']);
-        $table->addForeignKeyConstraint('article', ['article'], ['id'], ['deferrable' => true]);
-        $table->addForeignKeyConstraint('post', ['post'], ['id'], ['deferred' => true]);
-        $table->addForeignKeyConstraint('user', ['parent'], ['id'], ['deferrable' => true, 'deferred' => true]);
+        $table = Table::editor()
+            ->setUnquotedName('user')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('article')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('post')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('parent')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->setForeignKeyConstraints(
+                ForeignKeyConstraint::editor()
+                    ->setUnquotedReferencingColumnNames('article')
+                    ->setUnquotedReferencedTableName('article')
+                    ->setUnquotedReferencedColumnNames('id')
+                    ->setDeferrability(Deferrability::DEFERRABLE)
+                    ->create(),
+                ForeignKeyConstraint::editor()
+                    ->setUnquotedReferencingColumnNames('post')
+                    ->setUnquotedReferencedTableName('post')
+                    ->setUnquotedReferencedColumnNames('id')
+                    ->setDeferrability(Deferrability::DEFERRED)
+                    ->create(),
+                ForeignKeyConstraint::editor()
+                    ->setUnquotedReferencingColumnNames('parent')
+                    ->setUnquotedReferencedTableName('user')
+                    ->setUnquotedReferencedColumnNames('id')
+                    ->setDeferrability(Deferrability::DEFERRED)
+                    ->create(),
+            )
+            ->create();
 
         $sql = [
             'CREATE TABLE user ('
                 . 'id INTEGER NOT NULL, article INTEGER NOT NULL, post INTEGER NOT NULL, parent INTEGER NOT NULL'
-                . ', PRIMARY KEY(id)'
-                . ', CONSTRAINT FK_8D93D64923A0E66 FOREIGN KEY (article)'
+                . ', PRIMARY KEY (id)'
+                . ', FOREIGN KEY (article)'
                 . ' REFERENCES article (id) DEFERRABLE INITIALLY IMMEDIATE'
-                . ', CONSTRAINT FK_8D93D6495A8A6C8D FOREIGN KEY (post)'
-                . ' REFERENCES post (id) NOT DEFERRABLE INITIALLY DEFERRED'
-                . ', CONSTRAINT FK_8D93D6493D8E604F FOREIGN KEY (parent)'
+                . ', FOREIGN KEY (post)'
+                . ' REFERENCES post (id) DEFERRABLE INITIALLY DEFERRED'
+                . ', FOREIGN KEY (parent)'
                 . ' REFERENCES user (id) DEFERRABLE INITIALLY DEFERRED'
                 . ')',
             'CREATE INDEX IDX_8D93D64923A0E66 ON user (article)',
@@ -318,31 +399,82 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
 
     public function testAlterTable(): void
     {
-        $table = new Table('user');
-        $table->addColumn('id', Types::INTEGER);
-        $table->addColumn('article', Types::INTEGER);
-        $table->addColumn('post', Types::INTEGER);
-        $table->addColumn('parent', Types::INTEGER);
-        $table->setPrimaryKey(['id']);
-        $table->addForeignKeyConstraint('article', ['article'], ['id'], ['deferrable' => true]);
-        $table->addForeignKeyConstraint('post', ['post'], ['id'], ['deferred' => true]);
-        $table->addForeignKeyConstraint('user', ['parent'], ['id'], ['deferrable' => true, 'deferred' => true]);
-        $table->addIndex(['article', 'post'], 'index1');
+        $table = Table::editor()
+            ->setUnquotedName('user')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('article')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('post')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('parent')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->setIndexes(
+                Index::editor()
+                    ->setUnquotedName('index1')
+                    ->setUnquotedColumnNames('article', 'post')
+                    ->create(),
+            )
+            ->setForeignKeyConstraints(
+                ForeignKeyConstraint::editor()
+                    ->setUnquotedReferencingColumnNames('article')
+                    ->setUnquotedReferencedTableName('article')
+                    ->setUnquotedReferencedColumnNames('id')
+                    ->setDeferrability(Deferrability::DEFERRABLE)
+                    ->create(),
+                ForeignKeyConstraint::editor()
+                    ->setUnquotedReferencingColumnNames('post')
+                    ->setUnquotedReferencedTableName('post')
+                    ->setUnquotedReferencedColumnNames('id')
+                    ->setDeferrability(Deferrability::DEFERRED)
+                    ->create(),
+                ForeignKeyConstraint::editor()
+                    ->setUnquotedReferencingColumnNames('parent')
+                    ->setUnquotedReferencedTableName('user')
+                    ->setUnquotedReferencedColumnNames('id')
+                    ->setDeferrability(Deferrability::DEFERRED)
+                    ->create(),
+            )
+            ->create();
 
         $diff = new TableDiff(
             $table,
             changedColumns: [
                 'id' => new ColumnDiff(
                     $table->getColumn('id'),
-                    new Column('key', Type::getType(Types::INTEGER)),
+                    Column::editor()
+                        ->setUnquotedName('key')
+                        ->setTypeName(Types::INTEGER)
+                        ->create(),
                 ),
                 'post' => new ColumnDiff(
                     $table->getColumn('post'),
-                    new Column('comment', Type::getType(Types::INTEGER)),
+                    Column::editor()
+                        ->setUnquotedName('comment')
+                        ->setTypeName(Types::INTEGER)
+                        ->create(),
                 ),
             ],
             droppedColumns: [
-                new Column('parent', Type::getType(Types::INTEGER), []),
+                Column::editor()
+                    ->setUnquotedName('parent')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
             ],
             droppedIndexes: [
                 $table->getIndex('index1'),
@@ -354,11 +486,11 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
             'DROP TABLE user',
             'CREATE TABLE user ('
                 . '"key" INTEGER NOT NULL, article INTEGER NOT NULL, comment INTEGER NOT NULL'
-                . ', PRIMARY KEY("key")'
-                . ', CONSTRAINT FK_8D93D64923A0E66 FOREIGN KEY (article)'
+                . ', PRIMARY KEY ("key")'
+                . ', FOREIGN KEY (article)'
                 . ' REFERENCES article (id) DEFERRABLE INITIALLY IMMEDIATE'
-                . ', CONSTRAINT FK_8D93D6495A8A6C8D FOREIGN KEY (comment)'
-                . ' REFERENCES post (id) NOT DEFERRABLE INITIALLY DEFERRED'
+                . ', FOREIGN KEY (comment)'
+                . ' REFERENCES post (id) DEFERRABLE INITIALLY DEFERRED'
                 . ')',
             'INSERT INTO user ("key", article, comment) SELECT id, article, post FROM __temp__user',
             'DROP TABLE __temp__user',
@@ -374,7 +506,7 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
      */
     protected function getQuotedColumnInPrimaryKeySQL(): array
     {
-        return ['CREATE TABLE "quoted" ("create" VARCHAR(255) NOT NULL, PRIMARY KEY("create"))'];
+        return ['CREATE TABLE "quoted" ("create" VARCHAR(255) NOT NULL, PRIMARY KEY ("create"))'];
     }
 
     /**
@@ -413,7 +545,7 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
             'REFERENCES foo ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE, ' .
             'CONSTRAINT FK_WITH_INTENDED_QUOTATION FOREIGN KEY ("create", foo, "bar") ' .
             'REFERENCES "foo-bar" ("create", bar, "foo-bar") NOT DEFERRABLE INITIALLY IMMEDIATE)',
-            'CREATE INDEX IDX_22660D028FD6E0FB8C736521D79164E3 ON "quoted" ("create", foo, "bar")',
+            'CREATE INDEX IDX_22660D028FD6E0FB8C7365216D704F76 ON "quoted" ("create", foo, "bar")',
         ];
     }
 
@@ -445,7 +577,7 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
         return [
             'CREATE TEMPORARY TABLE __temp__mytable AS SELECT id FROM mytable',
             'DROP TABLE mytable',
-            'CREATE TABLE mytable (id INTEGER NOT NULL, PRIMARY KEY(id))',
+            'CREATE TABLE mytable (id INTEGER NOT NULL, PRIMARY KEY (id))',
             'INSERT INTO mytable (id) SELECT id FROM __temp__mytable',
             'DROP TABLE __temp__mytable',
             'CREATE INDEX idx_bar ON mytable (id)',
@@ -460,7 +592,7 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
         return [
             'CREATE TEMPORARY TABLE __temp__table AS SELECT id FROM "table"',
             'DROP TABLE "table"',
-            'CREATE TABLE "table" (id INTEGER NOT NULL, PRIMARY KEY(id))',
+            'CREATE TABLE "table" (id INTEGER NOT NULL, PRIMARY KEY (id))',
             'INSERT INTO "table" (id) SELECT id FROM __temp__table',
             'DROP TABLE __temp__table',
             'CREATE INDEX "select" ON "table" (id)',
@@ -491,13 +623,26 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
 
     public function testGeneratesAlterTableRenameColumnSQLWithSchema(): void
     {
-        $table = new Table('main.t');
-        $table->addColumn('a', Types::INTEGER);
+        $table = Table::editor()
+            ->setUnquotedName('t', 'main')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('a')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->create();
 
         $tableDiff = new TableDiff($table, changedColumns: [
             'a' => new ColumnDiff(
-                new Column('a', Type::getType(Types::INTEGER)),
-                new Column('b', Type::getType(Types::INTEGER)),
+                Column::editor()
+                    ->setUnquotedName('a')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('b')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
             ),
         ]);
 
@@ -619,13 +764,22 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
 
     public function testGetCreateTableSQLWithColumnCollation(): void
     {
-        $table = new Table('foo');
-        $table->addColumn('no_collation', Types::STRING, ['length' => 255]);
-        $table->addColumn(
-            'column_collation',
-            Types::STRING,
-            ['length' => 255],
-        )->setPlatformOption('collation', 'NOCASE');
+        $table = Table::editor()
+            ->setUnquotedName('foo')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('no_collation')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('column_collation')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(255)
+                    ->setCollation('NOCASE')
+                    ->create(),
+            )
+            ->create();
 
         self::assertSame(
             [
@@ -635,4 +789,47 @@ class SQLitePlatformTest extends AbstractPlatformTestCase
             $this->platform->getCreateTableSQL($table),
         );
     }
+
+    public function testCreateTableWithNonPrimaryKeyAutoIncrementColumn(): void
+    {
+        $table = Table::editor()
+            ->setUnquotedName('test_autoincrement')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->setAutoincrement(true)
+                    ->create(),
+            )
+            ->create();
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6849');
+        $this->platform->getCreateTableSQL($table);
+    }
+
+    public function testCreateTableWithCompositePrimaryKeyAutoIncrementColumn(): void
+    {
+        $table = Table::editor()
+            ->setUnquotedName('test_autoincrement')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id1')
+                    ->setTypeName(Types::INTEGER)
+                    ->setAutoincrement(true)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('id2')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id1', 'id2')
+                    ->create(),
+            )
+            ->create();
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/6849');
+        $this->platform->getCreateTableSQL($table);
+    }
 }
