@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Types;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
@@ -9,25 +11,33 @@ use PHPUnit\Framework\TestCase;
 
 class BooleanTest extends TestCase
 {
-    /** @var AbstractPlatform&MockObject */
-    private AbstractPlatform $platform;
-
+    private AbstractPlatform&MockObject $platform;
     private BooleanType $type;
 
     protected function setUp(): void
     {
-        $this->platform = $this->getMockForAbstractClass(AbstractPlatform::class);
+        $this->platform = $this->createMock(AbstractPlatform::class);
         $this->type     = new BooleanType();
     }
 
     public function testBooleanConvertsToDatabaseValue(): void
     {
-        self::assertIsInt($this->type->convertToDatabaseValue(1, $this->platform));
+        $this->platform->expects(self::once())
+            ->method('convertBooleansToDatabaseValue')
+            ->with(true)
+            ->willReturn(1);
+
+        self::assertSame(1, $this->type->convertToDatabaseValue(true, $this->platform));
     }
 
     public function testBooleanConvertsToPHPValue(): void
     {
-        self::assertIsBool($this->type->convertToPHPValue(0, $this->platform));
+        $this->platform->expects(self::once())
+            ->method('convertFromBoolean')
+            ->with(0)
+            ->willReturn(false);
+
+        self::assertFalse($this->type->convertToPHPValue(0, $this->platform));
     }
 
     public function testBooleanNullConvertsToPHPValue(): void
