@@ -1,12 +1,19 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Types;
 
-use Doctrine\DBAL\Types\ConversionException;
+use Doctrine\DBAL\Types\Exception\InvalidFormat;
+use Doctrine\DBAL\Types\Exception\InvalidType;
+use Doctrine\DBAL\Types\Exception\ValueNotConvertible;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 use stdClass;
 use Throwable;
 
+use function get_debug_type;
+use function sprintf;
 use function tmpfile;
 
 class ConversionExceptionTest extends TestCase
@@ -15,41 +22,33 @@ class ConversionExceptionTest extends TestCase
     {
         $previous = $this->createMock(Throwable::class);
 
-        $exception = ConversionException::conversionFailed('foo', 'foo', $previous);
+        $exception = ValueNotConvertible::new('foo', 'foo', null, $previous);
 
-        self::assertInstanceOf(ConversionException::class, $exception);
         self::assertSame($previous, $exception->getPrevious());
     }
 
-    /**
-     * @param mixed $scalarValue
-     *
-     * @dataProvider scalarsProvider
-     */
-    public function testConversionFailedInvalidTypeWithScalar($scalarValue, string $expected): void
+    #[DataProvider('scalarsProvider')]
+    public function testConversionFailedInvalidTypeWithScalar(mixed $scalarValue, string $expected): void
     {
-        $exception = ConversionException::conversionFailedInvalidType($scalarValue, 'foo', ['bar', 'baz']);
+        $exception = InvalidType::new($scalarValue, 'foo', ['bar', 'baz']);
 
-        self::assertInstanceOf(ConversionException::class, $exception);
         self::assertStringContainsString(
             $expected,
             $exception->getMessage(),
         );
     }
 
-    /**
-     * @param mixed $nonScalar
-     *
-     * @dataProvider nonScalarsProvider
-     */
-    public function testConversionFailedInvalidTypeWithNonScalar($nonScalar): void
+    #[DataProvider('nonScalarsProvider')]
+    public function testConversionFailedInvalidTypeWithNonScalar(mixed $nonScalar): void
     {
-        $exception = ConversionException::conversionFailedInvalidType($nonScalar, 'foo', ['bar', 'baz']);
+        $exception = InvalidType::new($nonScalar, 'foo', ['bar', 'baz']);
 
-        self::assertInstanceOf(ConversionException::class, $exception);
-        self::assertMatchesRegularExpression(
-            '/^Could not convert PHP value of type (.*) to type foo. '
-            . 'Expected one of the following types: bar, baz$/',
+        self::assertSame(
+            sprintf(
+                'Could not convert PHP value of type %s to type foo.'
+                    . ' Expected one of the following types: bar, baz.',
+                get_debug_type($nonScalar),
+            ),
             $exception->getMessage(),
         );
     }
@@ -58,9 +57,8 @@ class ConversionExceptionTest extends TestCase
     {
         $previous = $this->createMock(Throwable::class);
 
-        $exception = ConversionException::conversionFailedInvalidType('foo', 'foo', ['bar', 'baz'], $previous);
+        $exception = InvalidType::new('foo', 'foo', ['bar', 'baz'], $previous);
 
-        self::assertInstanceOf(ConversionException::class, $exception);
         self::assertSame($previous, $exception->getPrevious());
     }
 
@@ -68,9 +66,8 @@ class ConversionExceptionTest extends TestCase
     {
         $previous = $this->createMock(Throwable::class);
 
-        $exception = ConversionException::conversionFailedFormat('foo', 'bar', 'baz', $previous);
+        $exception = InvalidFormat::new('foo', 'bar', 'baz', $previous);
 
-        self::assertInstanceOf(ConversionException::class, $exception);
         self::assertSame($previous, $exception->getPrevious());
     }
 
