@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Types;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
@@ -9,9 +11,7 @@ use PHPUnit\Framework\TestCase;
 
 class GuidTypeTest extends TestCase
 {
-    /** @var AbstractPlatform&MockObject */
-    private AbstractPlatform $platform;
-
+    private AbstractPlatform&MockObject $platform;
     private GuidType $type;
 
     protected function setUp(): void
@@ -30,15 +30,4 @@ class GuidTypeTest extends TestCase
     {
         self::assertNull($this->type->convertToPHPValue(null, $this->platform));
     }
-
-    public function testNativeGuidSupport(): void
-    {
-        self::assertTrue($this->type->requiresSQLCommentHint($this->platform));
-
-        $this->platform->expects(self::any())
-             ->method('hasNativeGuidType')
-             ->willReturn(true);
-
-        self::assertFalse($this->type->requiresSQLCommentHint($this->platform));
-    }
 }
